@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 
@@ -25,7 +25,7 @@ import xml.dom.minidom
 # SET VERSION
 # -----------
 
-version = '4.0.0'
+version = '5.0.1'
 nightbuild = ''
 
 
@@ -87,13 +87,14 @@ main={
     'reverseScrolling': 0,
     'macListCtrlGeneric': 1,
     'peaklistColumns': ['mz', 'int', 'rel', 'sn', 'z', 'fwhm', 'resol'],
+    'cursorInfo': ['mz', 'dist', 'ppm', 'z'],
     'donate': '',
     'updatesEnabled': 1,
     'updatesChecked': '',
     'updatesCurrent': version,
     'updatesAvailable': version,
     'compassMode': 'Profile',
-    'compassFormat': 'mzData',
+    'compassFormat': 'mzML',
     'compassDeleteFile': 1,
 }
 
@@ -145,6 +146,7 @@ spectrum={
     'xLabel': 'm/z',
     'yLabel': 'a.i.',
     'showGrid': 1,
+    'showMinorTicks': 1,
     'showLegend': 1,
     'showPosBars': 1,
     'showGel': 1,
@@ -164,6 +166,7 @@ spectrum={
     'checkLimits': 1,
     'labelAngle': 90,
     'labelCharge': 1,
+    'labelGroup': 0,
     'labelBgr': 1,
     'labelFontSize': 10,
     'axisFontSize': 10,
@@ -189,8 +192,7 @@ match={
 
 processing={
     'math':{
-        'operation': 'add',
-        'spectrumB': '',
+        'operation': 'normalize',
         'multiplier': 1,
     },
     'crop':{
@@ -233,7 +235,16 @@ processing={
         'groupWindow': 0.01,
         'groupPeaks': 1,
         'forceGroupWindow': 0,
-    }
+    },
+    'batch':{
+        'math': 0,
+        'crop': 0,
+        'baseline': 0,
+        'smoothing': 0,
+        'peakpicking': 0,
+        'deisotoping': 0,
+        'deconvolution': 0,
+    },
 }
 
 calibration={
@@ -289,7 +300,7 @@ sequence={
     },
 }
 
-masscalc={
+massCalculator={
     'ionseriesAgent': 'H',
     'ionseriesAgentCharge': 1,
     'ionseriesPolarity': 1,
@@ -298,32 +309,59 @@ masscalc={
     'patternBaseline': 0,
     'patternShift': 0,
     'patternThreshold': 0.001,
+    'patternShowPeaks': 1,
 }
 
 massfilter={}
 
-compounds={
+massToFormula={
+    'charge': 1,
+    'ionization': 'H',
+    'tolerance': 1.,
+    'units': 'ppm',
+    'formulaMin': '',
+    'formulaMax': '',
+    'autoCHNO': 1,
+    'limit': 1000,
+    'rules': ['HC','NOPSC','NOPS','RDBE', 'RDBEInt'],
+    'HCMin': 0.1,
+    'HCMax': 3,
+    'NCMax': 4,
+    'OCMax': 3,
+    'PCMax': 2,
+    'SCMax': 3,
+    'RDBEMin': -1,
+    'RDBEMax': 40,
+    'PubChemScript': 'http://pubchem.ncbi.nlm.nih.gov/search/search.cgi',
+    'ChemSpiderScript': 'http://www.chemspider.com/Search.aspx',
+    'METLINScript': 'http://metlin.scripps.edu/metabo_list_adv.php',
+    'HMDBScript': 'http://www.hmdb.ca/search/search',
+    'LipidMAPSScript': 'http://www.lipidmaps.org/data/structure/LMSDSearch.php',
+}
+
+compoundsSearch={
     'massType': 0,
     'maxCharge': 1,
     'radicals': 0,
     'adducts':  ['Na','K'],
 }
 
-differences={
+peakDifferences={
     'aminoacids': 1,
     'dipeptides': 1,
     'massType': 0,
     'tolerance': 0.1,
+    'showAll': 1,
 }
 
-compare={
+comparePeaklists={
     'tolerance': 0.2,
     'units': 'Da',
     'ignoreCharge': 0,
     'compare': 'peaklists',
 }
 
-generator={
+spectrumGenerator={
     'fwhm': 0.1,
     'points': 10,
     'noise': 0,
@@ -333,7 +371,7 @@ generator={
     'showFlipped': 0,
 }
 
-envfit={
+envelopeFit={
     'loss': 'H',
     'gain': 'H{2}',
     'fit': 'spectrum',
@@ -499,9 +537,10 @@ links={
     'mMassHomepage': 'http://www.mmass.org/',
     'mMassForum': 'http://forum.mmass.org/',
     'mMassTwitter':  'http://www.twitter.com/mmassorg/',
-    'mMassCite': 'http://www.mmass.org/home/donate.php',
-    'mMassDonate': 'http://www.mmass.org/home/donate.php',
+    'mMassCite': 'http://www.mmass.org/donate/papers.php',
+    'mMassDonate': 'http://www.mmass.org/donate/',
     'mMassDownload': 'http://www.mmass.org/download/',
+    'mMassWhatsNew': 'http://www.mmass.org/download/history.php',
     
     'biomedmstools': 'http://ms.biomed.cas.cz/MSTools/',
     'blast': 'http://www.ebi.ac.uk/Tools/blastall/',
@@ -575,6 +614,9 @@ def loadConfig(path=os.path.join(confdir, 'config.xml')):
     if mainTags:
         _getParams(mainTags[0], main)
         
+        if type(main['cursorInfo']) != list:
+            main['cursorInfo'] = main['cursorInfo'].split(';')
+        
         if type(main['peaklistColumns']) != list:
             main['peaklistColumns'] = main['peaklistColumns'].split(';')
     
@@ -684,37 +726,45 @@ def loadConfig(path=os.path.join(confdir, 'config.xml')):
             sequence['fragment']['fragments'] = sequence['fragment']['fragments'].split(';')
     
     # mass calculator
-    masscalcTags = document.getElementsByTagName('masscalc')
-    if masscalcTags:
-        _getParams(masscalcTags[0], masscalc)
+    massCalculatorTags = document.getElementsByTagName('massCalculator')
+    if massCalculatorTags:
+        _getParams(massCalculatorTags[0], massCalculator)
+    
+    # mass to formula
+    massToFormulaTags = document.getElementsByTagName('massToFormula')
+    if massToFormulaTags:
+        _getParams(massToFormulaTags[0], massToFormula)
+        
+        if type(massToFormula['rules']) != list:
+            massToFormula['rules'] = massToFormula['rules'].split(';')
     
     # compounds search
-    compoundsTags = document.getElementsByTagName('compounds')
-    if compoundsTags:
-        _getParams(compoundsTags[0], compounds)
+    compoundsSearchTags = document.getElementsByTagName('compoundsSearch')
+    if compoundsSearchTags:
+        _getParams(compoundsSearchTags[0], compoundsSearch)
         
-        if type(compounds['adducts']) != list:
-            compounds['adducts'] = compounds['adducts'].split(';')
+        if type(compoundsSearch['adducts']) != list:
+            compoundsSearch['adducts'] = compoundsSearch['adducts'].split(';')
     
     # peak differences
-    differencesTags = document.getElementsByTagName('differences')
-    if differencesTags:
-        _getParams(differencesTags[0], differences)
+    peakDifferencesTags = document.getElementsByTagName('peakDifferences')
+    if peakDifferencesTags:
+        _getParams(peakDifferencesTags[0], peakDifferences)
     
     # compare peaklists
-    compareTags = document.getElementsByTagName('compare')
-    if compareTags:
-        _getParams(compareTags[0], compare)
+    comparePeaklistsTags = document.getElementsByTagName('comparePeaklists')
+    if comparePeaklistsTags:
+        _getParams(comparePeaklistsTags[0], comparePeaklists)
     
     # spectrum generator
-    generatorTags = document.getElementsByTagName('generator')
-    if generatorTags:
-        _getParams(generatorTags[0], generator)
+    spectrumGeneratorTags = document.getElementsByTagName('spectrumGenerator')
+    if spectrumGeneratorTags:
+        _getParams(spectrumGeneratorTags[0], spectrumGenerator)
     
     # envelope fit
-    envfitTags = document.getElementsByTagName('envfit')
-    if envfitTags:
-        _getParams(envfitTags[0], envfit)
+    envelopeFitTags = document.getElementsByTagName('envelopeFit')
+    if envelopeFitTags:
+        _getParams(envelopeFitTags[0], envelopeFit)
     
     # mascot
     mascotTags = document.getElementsByTagName('mascot')
@@ -804,6 +854,7 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="peaklistHeight" value="%d" type="int" />\n' % (main['peaklistHeight'])
     buff += '    <param name="reverseScrolling" value="%d" type="int" />\n' % (bool(main['reverseScrolling']))
     buff += '    <param name="macListCtrlGeneric" value="%d" type="int" />\n' % (bool(main['macListCtrlGeneric']))
+    buff += '    <param name="cursorInfo" value="%s" type="str" />\n' % (';'.join(main['cursorInfo']))
     buff += '    <param name="peaklistColumns" value="%s" type="str" />\n' % (';'.join(main['peaklistColumns']))
     buff += '    <param name="mzDigits" value="%d" type="int" />\n' % (main['mzDigits'])
     buff += '    <param name="intDigits" value="%d" type="int" />\n' % (main['intDigits'])
@@ -854,6 +905,7 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="xLabel" value="%s" type="unicode" />\n' % (_escape(spectrum['xLabel']))
     buff += '    <param name="yLabel" value="%s" type="unicode" />\n' % (_escape(spectrum['yLabel']))
     buff += '    <param name="showGrid" value="%d" type="int" />\n' % (bool(spectrum['showGrid']))
+    buff += '    <param name="showMinorTicks" value="%d" type="int" />\n' % (bool(spectrum['showMinorTicks']))
     buff += '    <param name="showLegend" value="%d" type="int" />\n' % (bool(spectrum['showLegend']))
     buff += '    <param name="showPosBars" value="%d" type="int" />\n' % (bool(spectrum['showPosBars']))
     buff += '    <param name="showGel" value="%d" type="int" />\n' % (bool(spectrum['showGel']))
@@ -872,6 +924,7 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="checkLimits" value="%d" type="int" />\n' % (bool(spectrum['checkLimits']))
     buff += '    <param name="labelAngle" value="%d" type="int" />\n' % (spectrum['labelAngle'])
     buff += '    <param name="labelCharge" value="%d" type="int" />\n' % (bool(spectrum['labelCharge']))
+    buff += '    <param name="labelGroup" value="%d" type="int" />\n' % (bool(spectrum['labelGroup']))
     buff += '    <param name="labelBgr" value="%d" type="int" />\n' % (bool(spectrum['labelBgr']))
     buff += '    <param name="labelFontSize" value="%d" type="int" />\n' % (spectrum['labelFontSize'])
     buff += '    <param name="axisFontSize" value="%d" type="int" />\n' % (spectrum['axisFontSize'])
@@ -937,6 +990,15 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '      <param name="groupPeaks" value="%d" type="int" />\n' % (bool(processing['deconvolution']['groupPeaks']))
     buff += '      <param name="forceGroupWindow" value="%d" type="int" />\n' % (bool(processing['deconvolution']['forceGroupWindow']))
     buff += '    </deconvolution>\n'
+    buff += '    <batch>\n'
+    buff += '      <param name="math" value="%d" type="int" />\n' % (bool(processing['batch']['math']))
+    buff += '      <param name="crop" value="%d" type="int" />\n' % (bool(processing['batch']['crop']))
+    buff += '      <param name="baseline" value="%d" type="int" />\n' % (bool(processing['batch']['baseline']))
+    buff += '      <param name="smoothing" value="%d" type="int" />\n' % (bool(processing['batch']['smoothing']))
+    buff += '      <param name="peakpicking" value="%d" type="int" />\n' % (bool(processing['batch']['peakpicking']))
+    buff += '      <param name="deisotoping" value="%d" type="int" />\n' % (bool(processing['batch']['deisotoping']))
+    buff += '      <param name="deconvolution" value="%d" type="int" />\n' % (bool(processing['batch']['deconvolution']))
+    buff += '    </batch>\n'
     buff += '  </processing>\n\n'
     
     # calibration
@@ -984,55 +1046,83 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '  </sequence>\n\n'
     
     # mass calculator
-    buff += '  <masscalc>\n'
-    buff += '    <param name="ionseriesAgent" value="%s" type="str" />\n' % (masscalc['ionseriesAgent'])
-    buff += '    <param name="ionseriesAgentCharge" value="%d" type="int" />\n' % (masscalc['ionseriesAgentCharge'])
-    buff += '    <param name="ionseriesPolarity" value="%d" type="int" />\n' % (masscalc['ionseriesPolarity'])
-    buff += '    <param name="patternFwhm" value="%f" type="float" />\n' % (masscalc['patternFwhm'])
-    buff += '    <param name="patternThreshold" value="%f" type="float" />\n' % (masscalc['patternThreshold'])
-    buff += '  </masscalc>\n\n'
+    buff += '  <massCalculator>\n'
+    buff += '    <param name="ionseriesAgent" value="%s" type="str" />\n' % (massCalculator['ionseriesAgent'])
+    buff += '    <param name="ionseriesAgentCharge" value="%d" type="int" />\n' % (massCalculator['ionseriesAgentCharge'])
+    buff += '    <param name="ionseriesPolarity" value="%d" type="int" />\n' % (massCalculator['ionseriesPolarity'])
+    buff += '    <param name="patternFwhm" value="%f" type="float" />\n' % (massCalculator['patternFwhm'])
+    buff += '    <param name="patternThreshold" value="%f" type="float" />\n' % (massCalculator['patternThreshold'])
+    buff += '    <param name="patternShowPeaks" value="%d" type="int" />\n' % (bool(massCalculator['patternShowPeaks']))
+    buff += '  </massCalculator>\n\n'
+    
+    # mass to formula
+    buff += '  <massToFormula>\n'
+    buff += '    <param name="charge" value="%d" type="int" />\n' % (massToFormula['charge'])
+    buff += '    <param name="ionization" value="%s" type="str" />\n' % (massToFormula['ionization'])
+    buff += '    <param name="tolerance" value="%f" type="float" />\n' % (massToFormula['tolerance'])
+    buff += '    <param name="units" value="%s" type="str" />\n' % (massToFormula['units'])
+    buff += '    <param name="formulaMin" value="%s" type="str" />\n' % (massToFormula['formulaMin'])
+    buff += '    <param name="formulaMax" value="%s" type="str" />\n' % (massToFormula['formulaMax'])
+    buff += '    <param name="autoCHNO" value="%d" type="int" />\n' % (bool(massToFormula['autoCHNO']))
+    buff += '    <param name="limit" value="%d" type="int" />\n' % (massToFormula['limit'])
+    buff += '    <param name="rules" value="%s" type="str" />\n' % (';'.join(massToFormula['rules']))
+    buff += '    <param name="HCMin" value="%f" type="float" />\n' % (massToFormula['HCMin'])
+    buff += '    <param name="HCMax" value="%f" type="float" />\n' % (massToFormula['HCMax'])
+    buff += '    <param name="NCMax" value="%f" type="float" />\n' % (massToFormula['NCMax'])
+    buff += '    <param name="OCMax" value="%f" type="float" />\n' % (massToFormula['OCMax'])
+    buff += '    <param name="PCMax" value="%f" type="float" />\n' % (massToFormula['PCMax'])
+    buff += '    <param name="SCMax" value="%f" type="float" />\n' % (massToFormula['SCMax'])
+    buff += '    <param name="RDBEMin" value="%f" type="float" />\n' % (massToFormula['RDBEMin'])
+    buff += '    <param name="RDBEMax" value="%f" type="float" />\n' % (massToFormula['RDBEMax'])
+    buff += '    <param name="PubChemScript" value="%s" type="unicode" />\n' % (_escape(massToFormula['PubChemScript']))
+    buff += '    <param name="ChemSpiderScript" value="%s" type="unicode" />\n' % (_escape(massToFormula['ChemSpiderScript']))
+    buff += '    <param name="METLINScript" value="%s" type="unicode" />\n' % (_escape(massToFormula['METLINScript']))
+    buff += '    <param name="HMDBScript" value="%s" type="unicode" />\n' % (_escape(massToFormula['HMDBScript']))
+    buff += '    <param name="LipidMAPSScript" value="%s" type="unicode" />\n' % (_escape(massToFormula['LipidMAPSScript']))
+    buff += '  </massToFormula>\n\n'
     
     # compounds search
-    buff += '  <compounds>\n'
-    buff += '    <param name="massType" value="%d" type="int" />\n' % (compounds['massType'])
-    buff += '    <param name="maxCharge" value="%d" type="int" />\n' % (compounds['maxCharge'])
-    buff += '    <param name="radicals" value="%d" type="int" />\n' % (bool(compounds['radicals']))
-    buff += '    <param name="adducts" value="%s" type="str" />\n' % (';'.join(compounds['adducts']))
-    buff += '  </compounds>\n\n'
+    buff += '  <compoundsSearch>\n'
+    buff += '    <param name="massType" value="%d" type="int" />\n' % (compoundsSearch['massType'])
+    buff += '    <param name="maxCharge" value="%d" type="int" />\n' % (compoundsSearch['maxCharge'])
+    buff += '    <param name="radicals" value="%d" type="int" />\n' % (bool(compoundsSearch['radicals']))
+    buff += '    <param name="adducts" value="%s" type="str" />\n' % (';'.join(compoundsSearch['adducts']))
+    buff += '  </compoundsSearch>\n\n'
     
     # peak differences
-    buff += '  <differences>\n'
-    buff += '    <param name="aminoacids" value="%d" type="int" />\n' % (bool(differences['aminoacids']))
-    buff += '    <param name="dipeptides" value="%d" type="int" />\n' % (bool(differences['dipeptides']))
-    buff += '    <param name="tolerance" value="%f" type="float" />\n' % (differences['tolerance'])
-    buff += '    <param name="massType" value="%d" type="int" />\n' % (differences['massType'])
-    buff += '  </differences>\n\n'
+    buff += '  <peakDifferences>\n'
+    buff += '    <param name="aminoacids" value="%d" type="int" />\n' % (bool(peakDifferences['aminoacids']))
+    buff += '    <param name="dipeptides" value="%d" type="int" />\n' % (bool(peakDifferences['dipeptides']))
+    buff += '    <param name="tolerance" value="%f" type="float" />\n' % (peakDifferences['tolerance'])
+    buff += '    <param name="massType" value="%d" type="int" />\n' % (peakDifferences['massType'])
+    buff += '    <param name="showAll" value="%d" type="int" />\n' % (bool(peakDifferences['showAll']))
+    buff += '  </peakDifferences>\n\n'
     
     # compare peaklists
-    buff += '  <compare>\n'
-    buff += '    <param name="tolerance" value="%f" type="float" />\n' % (compare['tolerance'])
-    buff += '    <param name="units" value="%s" type="str" />\n' % (compare['units'])
-    buff += '    <param name="ignoreCharge" value="%d" type="int" />\n' % (bool(compare['ignoreCharge']))
-    buff += '  </compare>\n\n'
+    buff += '  <comparePeaklists>\n'
+    buff += '    <param name="tolerance" value="%f" type="float" />\n' % (comparePeaklists['tolerance'])
+    buff += '    <param name="units" value="%s" type="str" />\n' % (comparePeaklists['units'])
+    buff += '    <param name="ignoreCharge" value="%d" type="int" />\n' % (bool(comparePeaklists['ignoreCharge']))
+    buff += '  </comparePeaklists>\n\n'
     
     # spectrum generator
-    buff += '  <generator>\n'
-    buff += '    <param name="fwhm" value="%f" type="float" />\n' % (generator['fwhm'])
-    buff += '    <param name="points" value="%d" type="int" />\n' % (generator['points'])
-    buff += '    <param name="noise" value="%f" type="float" />\n' % (generator['noise'])
-    buff += '    <param name="forceFwhm" value="%d" type="int" />\n' % (bool(generator['forceFwhm']))
-    buff += '    <param name="showPeaks" value="%d" type="int" />\n' % (bool(generator['showPeaks']))
-    buff += '    <param name="showOverlay" value="%d" type="int" />\n' % (bool(generator['showOverlay']))
-    buff += '  </generator>\n\n'
+    buff += '  <spectrumGenerator>\n'
+    buff += '    <param name="fwhm" value="%f" type="float" />\n' % (spectrumGenerator['fwhm'])
+    buff += '    <param name="points" value="%d" type="int" />\n' % (spectrumGenerator['points'])
+    buff += '    <param name="noise" value="%f" type="float" />\n' % (spectrumGenerator['noise'])
+    buff += '    <param name="forceFwhm" value="%d" type="int" />\n' % (bool(spectrumGenerator['forceFwhm']))
+    buff += '    <param name="showPeaks" value="%d" type="int" />\n' % (bool(spectrumGenerator['showPeaks']))
+    buff += '    <param name="showOverlay" value="%d" type="int" />\n' % (bool(spectrumGenerator['showOverlay']))
+    buff += '  </spectrumGenerator>\n\n'
     
     # envelope fit
-    buff += '  <envfit>\n'
-    buff += '    <param name="fit" value="%s" type="str" />\n' % (envfit['fit'])
-    buff += '    <param name="fwhm" value="%f" type="float" />\n' % (envfit['fwhm'])
-    buff += '    <param name="forceFwhm" value="%d" type="int" />\n' % (bool(envfit['forceFwhm']))
-    buff += '    <param name="autoAlign" value="%d" type="int" />\n' % (bool(envfit['autoAlign']))
-    buff += '    <param name="relThreshold" value="%f" type="float" />\n' % (envfit['relThreshold'])
-    buff += '  </envfit>\n\n'
+    buff += '  <envelopeFit>\n'
+    buff += '    <param name="fit" value="%s" type="str" />\n' % (envelopeFit['fit'])
+    buff += '    <param name="fwhm" value="%f" type="float" />\n' % (envelopeFit['fwhm'])
+    buff += '    <param name="forceFwhm" value="%d" type="int" />\n' % (bool(envelopeFit['forceFwhm']))
+    buff += '    <param name="autoAlign" value="%d" type="int" />\n' % (bool(envelopeFit['autoAlign']))
+    buff += '    <param name="relThreshold" value="%f" type="float" />\n' % (envelopeFit['relThreshold'])
+    buff += '  </envelopeFit>\n\n'
     
     # mascot
     buff += '  <mascot>\n'
@@ -1236,4 +1326,4 @@ def _escape(text):
 
 
 try: loadConfig()
-except: saveConfig()
+except IOError: saveConfig()
