@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -51,6 +51,7 @@ ID_documentColour = wx.NewId()
 ID_documentAnnotationEdit = wx.NewId()
 ID_documentAnnotationDelete = wx.NewId()
 ID_documentAnnotationSendToMassCalculator = wx.NewId()
+ID_documentAnnotationSendToMassToFormula = wx.NewId()
 ID_documentAnnotationSendToEnvelopeFit = wx.NewId()
 ID_documentAnnotationsDelete = wx.NewId()
 ID_documentAnnotationsCalibrateBy = wx.NewId()
@@ -84,6 +85,7 @@ HK_documentFlip = '\tAlt+Ctrl+F'
 
 # view
 ID_viewGrid = wx.NewId()
+ID_viewMinorTicks = wx.NewId()
 ID_viewLegend = wx.NewId()
 ID_viewPosBars = wx.NewId()
 ID_viewGel = wx.NewId()
@@ -93,9 +95,10 @@ ID_viewDataPoints = wx.NewId()
 ID_viewLabels = wx.NewId()
 ID_viewTicks = wx.NewId()
 ID_viewLabelCharge = wx.NewId()
+ID_viewLabelGroup = wx.NewId()
+ID_viewLabelBgr = wx.NewId()
 ID_viewLabelAngle = wx.NewId()
 ID_viewAllLabels = wx.NewId()
-ID_viewLabelBgr = wx.NewId()
 ID_viewOverlapLabels = wx.NewId()
 ID_viewNotations = wx.NewId()
 ID_viewNotationMarks = wx.NewId()
@@ -106,6 +109,12 @@ ID_viewNormalize = wx.NewId()
 ID_viewRange = wx.NewId()
 ID_viewCanvasProperties = wx.NewId()
 
+ID_viewSpectrumRulerMz = wx.NewId()
+ID_viewSpectrumRulerDist = wx.NewId()
+ID_viewSpectrumRulerPpm = wx.NewId()
+ID_viewSpectrumRulerZ = wx.NewId()
+ID_viewSpectrumRulerArea = wx.NewId()
+
 ID_viewPeaklistColumnMz = wx.NewId()
 ID_viewPeaklistColumnAi = wx.NewId()
 ID_viewPeaklistColumnBase = wx.NewId()
@@ -139,6 +148,7 @@ ID_processingBaseline = wx.NewId()
 ID_processingSmoothing = wx.NewId()
 ID_processingCrop = wx.NewId()
 ID_processingMath = wx.NewId()
+ID_processingBatch = wx.NewId()
 ID_toolsSwapData = wx.NewId()
 
 HK_processingUndo = '\tCtrl+Z'
@@ -179,6 +189,7 @@ ID_toolsMeasure = wx.NewId()
 ID_toolsOffset = wx.NewId()
 ID_toolsPeriodicTable = wx.NewId()
 ID_toolsMassCalculator = wx.NewId()
+ID_toolsMassToFormula = wx.NewId()
 ID_toolsMassFilter = wx.NewId()
 ID_toolsCompoundsSearch = wx.NewId()
 ID_toolsPeakDifferences = wx.NewId()
@@ -200,6 +211,7 @@ HK_toolsDeleteLabel = '\tShift+Ctrl+X'
 HK_toolsMeasure = '\tShift+Ctrl+H'
 HK_toolsPeriodicTable = '\tShift+Ctrl+T'
 HK_toolsMassCalculator = '\tShift+Ctrl+M'
+HK_toolsMassToFormula = '\tShift+Ctrl+B'
 HK_toolsMassFilter = '\tShift+Ctrl+F'
 HK_toolsCompoundsSearch = '\tShift+Ctrl+U'
 HK_toolsPeakDifferences = '\tShift+Ctrl+D'
@@ -242,6 +254,11 @@ ID_windowLayout2 = wx.NewId()
 ID_windowLayout3 = wx.NewId()
 ID_windowLayout4 = wx.NewId()
 
+HK_windowLayout1 = '\tF5'
+HK_windowLayout2 = '\tF6'
+HK_windowLayout3 = '\tF7'
+HK_windowLayout4 = '\tF8'
+
 # help
 ID_helpAbout = wx.ID_ABOUT
 ID_helpHomepage = wx.NewId()
@@ -251,21 +268,36 @@ ID_helpCite = wx.NewId()
 ID_helpDonate = wx.NewId()
 ID_helpUpdate = wx.NewId()
 ID_helpUserGuide = wx.NewId()
+ID_helpDownload = wx.NewId()
+ID_helpWhatsNew = wx.NewId()
 
-# calibration panel
-ID_calibrationReferences = wx.NewId()
-ID_calibrationErrors = wx.NewId()
+HK_helpUserGuide = '\tF1'
+
+# peaklist panel
+ID_peaklistAnnotate = wx.NewId()
+ID_peaklistSendToMassToFormula = wx.NewId()
 
 # match panel
 ID_matchErrors = wx.NewId()
 ID_matchSummary = wx.NewId()
 
-# masscalc panel
+# calibration panel
+ID_calibrationReferences = wx.NewId()
+ID_calibrationErrors = wx.NewId()
+
+# mass calculator panel
 ID_massCalculatorSummary = wx.NewId()
 ID_massCalculatorIonSeries = wx.NewId()
 ID_massCalculatorPattern = wx.NewId()
 ID_massCalculatorCollapse = wx.NewId()
 
+# mass to formula panel
+ID_massToFormulaSearchPubChem = wx.NewId()
+ID_massToFormulaSearchChemSpider = wx.NewId()
+ID_massToFormulaSearchMETLIN = wx.NewId()
+ID_massToFormulaSearchHMDB = wx.NewId()
+ID_massToFormulaSearchLipidMaps = wx.NewId()
+
 # coumpounds search panel
 ID_compoundsSearchCompounds = wx.NewId()
 ID_compoundsSearchFormula = wx.NewId()
