@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -556,6 +556,10 @@ def loadPresets(path=os.path.join(config.confdir, 'presets.xml'), clear=True, re
                 deconvolutionTags = presetsTag.getElementsByTagName('deconvolution')
                 if deconvolutionTags:
                     _getParams(deconvolutionTags[0], container['processing'][name]['deconvolution'])
+                
+                batchTags = presetsTag.getElementsByTagName('batch')
+                if batchTags:
+                    _getParams(batchTags[0], container['processing'][name]['batch'])
     
     # get modifications presets
     modificationsTags = document.getElementsByTagName('modifications')
@@ -795,6 +799,15 @@ def savePresets(path=os.path.join(config.confdir, 'presets.xml')):
         buff += '        <param name="groupPeaks" value="%d" type="int" />\n' % (bool(item['deconvolution']['groupPeaks']))
         buff += '        <param name="forceGroupWindow" value="%d" type="int" />\n' % (bool(item['deconvolution']['forceGroupWindow']))
         buff += '      </deconvolution>\n'
+        buff += '      <batch>\n'
+        buff += '        <param name="math" value="%d" type="int" />\n' % (bool(item['batch']['math']))
+        buff += '        <param name="crop" value="%d" type="int" />\n' % (bool(item['batch']['crop']))
+        buff += '        <param name="baseline" value="%d" type="int" />\n' % (bool(item['batch']['baseline']))
+        buff += '        <param name="smoothing" value="%d" type="int" />\n' % (bool(item['batch']['smoothing']))
+        buff += '        <param name="peakpicking" value="%d" type="int" />\n' % (bool(item['batch']['peakpicking']))
+        buff += '        <param name="deisotoping" value="%d" type="int" />\n' % (bool(item['batch']['deisotoping']))
+        buff += '        <param name="deconvolution" value="%d" type="int" />\n' % (bool(item['batch']['deconvolution']))
+        buff += '      </batch>\n'
         buff += '    </presets>\n\n'
     buff += '  </processing>\n\n'
     
