@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -57,13 +57,13 @@ BOTTOMBAR_HEIGHT = 22
 BOTTOMBAR_LSPACE = 0
 BOTTOMBAR_RSPACE = 0
 BOTTOMBAR_TOOLSIZE = (-1,-1)
-SMALL_COMBO_HEIGHT = -1
+SMALL_CHOICE_HEIGHT = -1
 SMALL_BUTTON_HEIGHT = 22
 SMALL_TEXTCTRL_HEIGHT = -1
 SMALL_SEARCH_HEIGHT = -1
 BUTTON_SIZE_CORRECTION = 0
 
-COMBO_HEIGHT = -1
+CHOICE_HEIGHT = -1
 
 LISTCTRL_STYLE_SINGLE = wx.LC_REPORT|wx.LC_SINGLE_SEL|wx.LC_VRULES|wx.LC_HRULES|wx.SUNKEN_BORDER
 LISTCTRL_STYLE_MULTI = wx.LC_REPORT|wx.LC_VRULES|wx.LC_HRULES|wx.SUNKEN_BORDER
@@ -101,7 +101,7 @@ if wx.Platform == '__WXMAC__':
     GAUGE_HEIGHT = 11
     GAUGE_SPACE = 15
     
-    MAIN_TOOLBAR_TOOLSIZE = (30,23)
+    MAIN_TOOLBAR_TOOLSIZE = (32,23)
     MAIN_TOOLBAR_STYLE = wx.TB_FLAT|wx.TB_NODIVIDER|wx.TB_HORIZONTAL|wx.TB_TEXT
     
     TOOLBAR_HEIGHT = 38
@@ -112,13 +112,13 @@ if wx.Platform == '__WXMAC__':
     BOTTOMBAR_HEIGHT = 33
     BOTTOMBAR_LSPACE = 10
     BOTTOMBAR_RSPACE = 10
-    SMALL_COMBO_HEIGHT = 22
+    SMALL_CHOICE_HEIGHT = 22
     SMALL_BUTTON_HEIGHT = -1
     SMALL_TEXTCTRL_HEIGHT = 18
     SMALL_SEARCH_HEIGHT = 22
     BUTTON_SIZE_CORRECTION = -3
     
-    COMBO_HEIGHT = 22
+    CHOICE_HEIGHT = 22
     
     LISTCTRL_STYLE_SINGLE = wx.LC_REPORT|wx.LC_SINGLE_SEL|wx.LC_VRULES|wx.NO_BORDER
     LISTCTRL_STYLE_MULTI = wx.LC_REPORT|wx.LC_VRULES|wx.NO_BORDER
@@ -148,7 +148,7 @@ if wx.Platform == '__WXMAC__':
 
 # set windows
 elif wx.Platform == '__WXMSW__':
-    SMALL_COMBO_HEIGHT = 22
+    SMALL_CHOICE_HEIGHT = 22
     SMALL_BUTTON_HEIGHT = 22
     SMALL_SEARCH_HEIGHT = 22
     
@@ -163,7 +163,7 @@ elif wx.Platform == '__WXGTK__':
     TOOLBAR_TOOLSIZE = (32,26)
     BOTTOMBAR_HEIGHT = 28
     BOTTOMBAR_TOOLSIZE = (32,26)
-    SMALL_COMBO_HEIGHT = 25
+    SMALL_CHOICE_HEIGHT = 25
     SMALL_BUTTON_HEIGHT = 25
     SMALL_TEXTCTRL_HEIGHT = 25
     SMALL_SEARCH_HEIGHT = 25
@@ -243,8 +243,8 @@ class sortListCtrl(wx.ListCtrl):
         self._altColour = self.GetBackgroundColour()
         self._currentAttr = wx.ListItemAttr()
         
-        self._getItemTextFce = None
-        self._getItemAttrFce = None
+        self._getItemTextFn = None
+        self._getItemAttrFn = None
         
         # set events
         self.Bind(wx.EVT_LIST_COL_CLICK, self._onColClick, self)
@@ -254,8 +254,8 @@ class sortListCtrl(wx.ListCtrl):
     def OnGetItemText(self, row, col):
         """Get text for selected cell."""
         
-        if self._getItemTextFce != None:
-            return self._getItemTextFce(row, col)
+        if self._getItemTextFn != None:
+            return self._getItemTextFn(row, col)
         else:
             return unicode(self._data[row][col])
     # ----
@@ -266,8 +266,8 @@ class sortListCtrl(wx.ListCtrl):
         
         # get user defined attr
         attr = None
-        if self._getItemAttrFce != None:
-            attr = self._getItemAttrFce(row)
+        if self._getItemAttrFn != None:
+            attr = self._getItemAttrFn(row)
         
         # set background colour
         if attr and attr.HasBackgroundColour():
@@ -379,15 +379,15 @@ class sortListCtrl(wx.ListCtrl):
     # ----
     
     
-    def setItemTextFce(self, fce):
+    def setItemTextFn(self, fn):
         """Set OnGetItemText callback."""
-        self._getItemTextFce = fce
+        self._getItemTextFn = fn
     # ----
     
     
-    def setItemAttrFce(self, fce):
+    def setItemAttrFn(self, fn):
         """Set OnGetItemAttr callback."""
-        self._getItemAttrFce = fce
+        self._getItemAttrFn = fn
     # ----
     
     
