@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -78,18 +78,18 @@ class panelComparePeaklists(wx.MiniFrame):
         compare_label.SetFont(wx.SMALL_FONT)
         
         choices = ['Peak Lists', 'Notations (measured)', 'Notations (theoretical)']
-        self.compare_combo = wx.ComboBox(panel, -1, choices=choices, size=(180, mwx.SMALL_COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.compare_combo.Bind(wx.EVT_COMBOBOX, self.onCompareChanged)
-        self.compare_combo.Select(0)
-        if config.compare['compare'] == 'measured':
-            self.compare_combo.Select(1)
-        elif config.compare['compare'] == 'theoretical':
-            self.compare_combo.Select(2)
+        self.compare_choice = wx.Choice(panel, -1, choices=choices, size=(180, mwx.SMALL_CHOICE_HEIGHT))
+        self.compare_choice.Bind(wx.EVT_CHOICE, self.onCompareChanged)
+        self.compare_choice.Select(0)
+        if config.comparePeaklists['compare'] == 'measured':
+            self.compare_choice.Select(1)
+        elif config.comparePeaklists['compare'] == 'theoretical':
+            self.compare_choice.Select(2)
         
         tolerance_label = wx.StaticText(panel, -1, "Tolerance:")
         tolerance_label.SetFont(wx.SMALL_FONT)
         
-        self.tolerance_value = wx.TextCtrl(panel, -1, str(config.compare['tolerance']), size=(60, -1), style=wx.TE_PROCESS_ENTER, validator=mwx.validator('floatPos'))
+        self.tolerance_value = wx.TextCtrl(panel, -1, str(config.comparePeaklists['tolerance']), size=(60, -1), style=wx.TE_PROCESS_ENTER, validator=mwx.validator('floatPos'))
         self.tolerance_value.Bind(wx.EVT_TEXT_ENTER, self.onCompare)
         
         self.unitsDa_radio = wx.RadioButton(panel, -1, "Da", style=wx.RB_GROUP)
@@ -98,21 +98,20 @@ class panelComparePeaklists(wx.MiniFrame):
         
         self.unitsPpm_radio = wx.RadioButton(panel, -1, "ppm")
         self.unitsPpm_radio.SetFont(wx.SMALL_FONT)
-        self.unitsPpm_radio.SetValue((config.compare['units'] == 'ppm'))
+        self.unitsPpm_radio.SetValue((config.comparePeaklists['units'] == 'ppm'))
         
         self.ignoreCharge_check = wx.CheckBox(panel, -1, "Ignore charge")
         self.ignoreCharge_check.SetFont(wx.SMALL_FONT)
-        self.ignoreCharge_check.SetValue(config.compare['ignoreCharge'])
+        self.ignoreCharge_check.SetValue(config.comparePeaklists['ignoreCharge'])
         
         self.compare_butt = wx.Button(panel, -1, "Compare", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.compare_butt.SetFont(wx.SMALL_FONT)
         self.compare_butt.Bind(wx.EVT_BUTTON, self.onCompare)
         
         # pack elements
         sizer = wx.BoxSizer(wx.HORIZONTAL)
         sizer.AddSpacer(mwx.CONTROLBAR_LSPACE)
         sizer.Add(compare_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
-        sizer.Add(self.compare_combo, 0, wx.ALIGN_CENTER_VERTICAL)
+        sizer.Add(self.compare_choice, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddSpacer(20)
         sizer.Add(tolerance_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
         sizer.Add(self.tolerance_value, 0, wx.ALIGN_CENTER_VERTICAL)
@@ -232,13 +231,13 @@ class panelComparePeaklists(wx.MiniFrame):
         """Get relevant peaks lists."""
         
         # get data type
-        value = self.compare_combo.GetValue()
+        value = self.compare_choice.GetStringSelection()
         if value == 'Notations (measured)':
-            config.compare['compare'] = 'measured'
+            config.comparePeaklists['compare'] = 'measured'
         elif value == 'Notations (theoretical)':
-            config.compare['compare'] = 'theoretical'
+            config.comparePeaklists['compare'] = 'theoretical'
         else:
-            config.compare['compare'] = 'peaklists'
+            config.comparePeaklists['compare'] = 'peaklists'
         
         # get peaklists
         self.getPeaklists()
@@ -340,17 +339,17 @@ class panelComparePeaklists(wx.MiniFrame):
         # try to get values
         try:
             
-            config.compare['tolerance'] = float(self.tolerance_value.GetValue())
+            config.comparePeaklists['tolerance'] = float(self.tolerance_value.GetValue())
             
             if self.unitsDa_radio.GetValue():
-                config.compare['units'] = 'Da'
+                config.comparePeaklists['units'] = 'Da'
             else:
-                config.compare['units'] = 'ppm'
+                config.comparePeaklists['units'] = 'ppm'
             
             if self.ignoreCharge_check.GetValue():
-                config.compare['ignoreCharge'] = 1
+                config.comparePeaklists['ignoreCharge'] = 1
             else:
-                config.compare['ignoreCharge'] = 0
+                config.comparePeaklists['ignoreCharge'] = 0
             
             return True
             
@@ -373,7 +372,7 @@ class panelComparePeaklists(wx.MiniFrame):
             self.currentPeaklists.append([])
             
             # use measured notations
-            if config.compare['compare'] == 'measured':
+            if config.comparePeaklists['compare'] == 'measured':
                 items = []
                 for item in document.annotations:
                     items.append(item)
@@ -385,7 +384,7 @@ class panelComparePeaklists(wx.MiniFrame):
                     self.currentPeaklists[-1][-1][-1][x] = True
             
             # use theoretical notations
-            elif config.compare['compare'] == 'theoretical':
+            elif config.comparePeaklists['compare'] == 'theoretical':
                 items = []
                 for item in document.annotations:
                     if item.theoretical != None:
@@ -485,7 +484,7 @@ class panelComparePeaklists(wx.MiniFrame):
         # set formats
         mzFormat = '%0.' + `config.main['mzDigits']` + 'f'
         errFormat = '%0.' + `config.main['mzDigits']` + 'f'
-        if config.compare['units'] == 'ppm':
+        if config.comparePeaklists['units'] == 'ppm':
             errFormat = '%0.' + `config.main['ppmDigits']` + 'f'
         
         # add data
@@ -531,12 +530,12 @@ class panelComparePeaklists(wx.MiniFrame):
                 p2 = peaklist[j]
                 
                 # check charge
-                if not config.compare['ignoreCharge'] and (p1[1] != p2[1]) and (p1[1] != None and p2[1] != None):
+                if not config.comparePeaklists['ignoreCharge'] and (p1[1] != p2[1]) and (p1[1] != None and p2[1] != None):
                     continue
                 
                 # check error
-                error = mspy.delta(p1[0], p2[0], config.compare['units'])
-                if abs(error) <= config.compare['tolerance']:
+                error = mspy.delta(p1[0], p2[0], config.comparePeaklists['units'])
+                if abs(error) <= config.comparePeaklists['tolerance']:
                     self.currentPeaklists[p1[2]][p1[3]][-1][p2[2]] = True
                     self.currentPeaklists[p2[2]][p2[3]][-1][p1[2]] = True
                 elif error < 0:
@@ -565,12 +564,12 @@ class panelComparePeaklists(wx.MiniFrame):
         for p2 in peaklist:
             
             # check charge
-            if not config.compare['ignoreCharge'] and (p1[1] != p2[1]) and (p1[1] != None and p2[1] != None):
+            if not config.comparePeaklists['ignoreCharge'] and (p1[1] != p2[1]) and (p1[1] != None and p2[1] != None):
                 continue
             
             # check error
-            error = mspy.delta(p1[0], p2[0], config.compare['units'])
-            if abs(error) <= config.compare['tolerance']:
+            error = mspy.delta(p1[0], p2[0], config.comparePeaklists['units'])
+            if abs(error) <= config.comparePeaklists['tolerance']:
                 ratio1 = p1[2]/p2[2]
                 ratio2 = 1/ratio1
                 self.currentMatches.append([p2[3], p2[0], error, ratio1, ratio2, p2[3]==docIndex])
