@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -209,8 +209,8 @@ class panelDocumentInfo(wx.MiniFrame):
         self.precursorCharge_value.Bind(wx.EVT_TEXT, self.onSave)
         
         polarity_label = wx.StaticText(panel, -1, "Polarity:")
-        self.polarity_combo = wx.ComboBox(panel, -1, choices=['Unknown', 'Positive', 'Negative'], size=(180, mwx.SMALL_COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.polarity_combo.Bind(wx.EVT_COMBOBOX, self.onSave)
+        self.polarity_choice = wx.Choice(panel, -1, choices=['Unknown', 'Positive', 'Negative'], size=(180, mwx.SMALL_CHOICE_HEIGHT))
+        self.polarity_choice.Bind(wx.EVT_CHOICE, self.onSave)
         
         points_label = wx.StaticText(panel, -1, "Spectrum points:")
         self.points_value = wx.TextCtrl(panel, -1, "", size=(180, -1))
@@ -233,7 +233,7 @@ class panelDocumentInfo(wx.MiniFrame):
         grid.Add(precursorCharge_label, (4,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
         grid.Add(self.precursorCharge_value, (4,1))
         grid.Add(polarity_label, (5,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
-        grid.Add(self.polarity_combo, (5,1))
+        grid.Add(self.polarity_choice, (5,1))
         grid.Add(points_label, (6,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
         grid.Add(self.points_value, (6,1))
         grid.Add(peaklist_label, (7,0), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
@@ -401,7 +401,7 @@ class panelDocumentInfo(wx.MiniFrame):
         # update title
         if self.currentDocument.title != self.title_value.GetValue():
             self.currentDocument.title = self.title_value.GetValue()
-            self.parent.onDocumentChanged(('doctitle'))
+            self.parent.onDocumentChanged(items=('doctitle'))
         
         # save data to document
         self.currentDocument.date = self.date_value.GetValue()
@@ -426,15 +426,15 @@ class panelDocumentInfo(wx.MiniFrame):
         try: self.currentDocument.spectrum.precursorCharge = int(self.precursorCharge_value.GetValue())
         except: self.currentDocument.spectrum.precursorCharge = None
         
-        if self.polarity_combo.GetValue() == 'Positive':
+        if self.polarity_choice.GetStringSelection() == 'Positive':
             self.currentDocument.spectrum.polarity = 1
-        elif self.polarity_combo.GetValue() == 'Negative':
+        elif self.polarity_choice.GetStringSelection() == 'Negative':
             self.currentDocument.spectrum.polarity = -1
         else:
             self.currentDocument.spectrum.polarity = None
         
         # set document dirty
-        self.parent.onDocumentChanged(('info'))
+        self.parent.onDocumentChanged(items=('info'))
     # ----
     
     
@@ -457,7 +457,7 @@ class panelDocumentInfo(wx.MiniFrame):
         self.msLevel_value.ChangeValue('')
         self.precursorMZ_value.ChangeValue('')
         self.precursorCharge_value.ChangeValue('')
-        self.polarity_combo.SetValue('Unknown')
+        self.polarity_choice.SetStringSelection('Unknown')
         self.points_value.ChangeValue('')
         self.peaklist_value.ChangeValue('')
         self.notes_value.ChangeValue('')
@@ -485,13 +485,13 @@ class panelDocumentInfo(wx.MiniFrame):
                 self.precursorCharge_value.ChangeValue(str(document.spectrum.precursorCharge))
             
             if document.spectrum.polarity == 1:
-                self.polarity_combo.SetValue('Positive')
+                self.polarity_choice.SetStringSelection('Positive')
             elif document.spectrum.polarity == -1:
-                self.polarity_combo.SetValue('Negative')
+                self.polarity_choice.SetStringSelection('Negative')
             else:
-                self.polarity_combo.SetValue('Unknown')
+                self.polarity_choice.SetStringSelection('Unknown')
             
-            self.points_value.ChangeValue(str(len(document.spectrum.points)))
+            self.points_value.ChangeValue(str(len(document.spectrum.profile)))
             self.peaklist_value.ChangeValue(str(len(document.spectrum.peaklist)))
     # ----
     
