@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -45,6 +45,9 @@ class panelEnvelopeFit(wx.MiniFrame):
         self.currentCompound = None
         self.currentFit = None
         
+        # init container
+        self.spectrumContainer = mspy.plot.container([])
+        
         # make gui items
         self.makeGUI()
         wx.EVT_CLOSE(self, self.onClose)
@@ -93,24 +96,23 @@ class panelEnvelopeFit(wx.MiniFrame):
         
         charge_label = wx.StaticText(panel, -1, "Charge:")
         charge_label.SetFont(wx.SMALL_FONT)
-        self.charge_value = wx.TextCtrl(panel, -1, str(config.envfit['charge']), size=(35,  -1), validator=mwx.validator('int'))
+        self.charge_value = wx.TextCtrl(panel, -1, str(config.envelopeFit['charge']), size=(35,  -1), validator=mwx.validator('int'))
         
         exchange_label = wx.StaticText(panel, -1, "Exchange:")
         exchange_label.SetFont(wx.SMALL_FONT)
-        self.exchangeLoss_value = mwx.formulaCtrl(panel, -1, str(config.envfit['loss']), size=(40,  -1))
+        self.exchangeLoss_value = mwx.formulaCtrl(panel, -1, str(config.envelopeFit['loss']), size=(40,  -1))
         exchangeVs_label = wx.StaticText(panel, -1, " vs.")
         exchangeVs_label.SetFont(wx.SMALL_FONT)
-        self.exchangeGain_value = mwx.formulaCtrl(panel, -1, str(config.envfit['gain']), size=(40,  -1))
+        self.exchangeGain_value = mwx.formulaCtrl(panel, -1, str(config.envelopeFit['gain']), size=(40,  -1))
         
         scale_label = wx.StaticText(panel, -1, "Range:")
         scale_label.SetFont(wx.SMALL_FONT)
         scaleDash_label = wx.StaticText(panel, -1, "-")
         scaleDash_label.SetFont(wx.SMALL_FONT)
-        self.scaleMin_value = wx.TextCtrl(panel, -1, str(config.envfit['scaleMin']), size=(35,  -1), validator=mwx.validator('intPos'))
-        self.scaleMax_value = wx.TextCtrl(panel, -1, str(config.envfit['scaleMax']), size=(35,  -1), validator=mwx.validator('intPos'))
+        self.scaleMin_value = wx.TextCtrl(panel, -1, str(config.envelopeFit['scaleMin']), size=(35,  -1), validator=mwx.validator('intPos'))
+        self.scaleMax_value = wx.TextCtrl(panel, -1, str(config.envelopeFit['scaleMax']), size=(35,  -1), validator=mwx.validator('intPos'))
         
         self.calculate_butt = wx.Button(panel, -1, "Calculate", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.calculate_butt.SetFont(wx.SMALL_FONT)
         self.calculate_butt.Bind(wx.EVT_BUTTON, self.onCalculate)
         
         # pack elements
@@ -165,28 +167,28 @@ class panelEnvelopeFit(wx.MiniFrame):
         self.fitToSpectrum_radio.SetFont(wx.SMALL_FONT)
         
         self.fitToPeaklist_radio.SetValue(True)
-        if config.envfit['fit'] == 'spectrum':
+        if config.envelopeFit['fit'] == 'spectrum':
             self.fitToSpectrum_radio.SetValue(True)
         
         fwhm_label = wx.StaticText(panel, -1, "Default FWHM:")
         fwhm_label.SetFont(wx.SMALL_FONT)
-        self.fwhm_value = wx.TextCtrl(panel, -1, str(config.envfit['fwhm']), size=(50, mwx.SMALL_TEXTCTRL_HEIGHT), validator=mwx.validator('floatPos'))
+        self.fwhm_value = wx.TextCtrl(panel, -1, str(config.envelopeFit['fwhm']), size=(50, mwx.SMALL_TEXTCTRL_HEIGHT), validator=mwx.validator('floatPos'))
         self.fwhm_value.SetFont(wx.SMALL_FONT)
         
         self.forceFwhm_check = wx.CheckBox(panel, -1, "Force")
         self.forceFwhm_check.SetFont(wx.SMALL_FONT)
-        self.forceFwhm_check.SetValue(config.envfit['forceFwhm'])
+        self.forceFwhm_check.SetValue(config.envelopeFit['forceFwhm'])
         
         relThreshold_label = wx.StaticText(panel, -1, "Rel. threshold:")
         relThreshold_label.SetFont(wx.SMALL_FONT)
         relThresholdUnits_label = wx.StaticText(panel, -1, "%")
         relThresholdUnits_label.SetFont(wx.SMALL_FONT)
-        self.relThreshold_value = wx.TextCtrl(panel, -1, str(config.envfit['relThreshold']*100), size=(50, mwx.SMALL_TEXTCTRL_HEIGHT), validator=mwx.validator('floatPos'))
+        self.relThreshold_value = wx.TextCtrl(panel, -1, str(config.envelopeFit['relThreshold']*100), size=(50, mwx.SMALL_TEXTCTRL_HEIGHT), validator=mwx.validator('floatPos'))
         self.relThreshold_value.SetFont(wx.SMALL_FONT)
         
         self.autoAlign_check = wx.CheckBox(panel, -1, "Auto align")
         self.autoAlign_check.SetFont(wx.SMALL_FONT)
-        self.autoAlign_check.SetValue(config.envfit['autoAlign'])
+        self.autoAlign_check.SetValue(config.envelopeFit['autoAlign'])
         
         self.average_label = wx.StaticText(panel, -1, "", size=(100, -1))
         self.average_label.SetFont(wx.SMALL_FONT)
@@ -252,28 +254,20 @@ class panelEnvelopeFit(wx.MiniFrame):
         self.spectrumCanvas = mspy.plot.canvas(panel, size=(600, 350), style=mwx.PLOTCANVAS_STYLE_PANEL)
         
         # set default params
-        self.spectrumCanvas.setProperties(xLabel='m/z')
-        self.spectrumCanvas.setProperties(yLabel='a.i.')
+        self.updateCanvasProperties(refresh=False)
+        self.spectrumCanvas.setProperties(showZero=False)
         self.spectrumCanvas.setProperties(showLegend=True)
         self.spectrumCanvas.setProperties(showPosBar=False)
         self.spectrumCanvas.setProperties(showIntBar=True)
-        self.spectrumCanvas.setProperties(intBarHeight=6)
         self.spectrumCanvas.setProperties(showGel=False)
         self.spectrumCanvas.setProperties(checkLimits=True)
         self.spectrumCanvas.setProperties(autoScaleY=True)
-        self.spectrumCanvas.setProperties(overlapLabels=False)
-        self.spectrumCanvas.setProperties(xPosDigits=5)
-        self.spectrumCanvas.setProperties(yPosDigits=2)
-        self.spectrumCanvas.setProperties(distanceDigits=5)
         self.spectrumCanvas.setProperties(reverseScrolling=config.main['reverseScrolling'])
         self.spectrumCanvas.setProperties(reverseDrawing=False)
+        
         self.spectrumCanvas.setLMBFunction('xDistance')
-        self.spectrumCanvas.setMFunction('cross')
         
-        axisFont = wx.Font(config.spectrum['axisFontSize'], wx.SWISS, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL, 0)
-        self.spectrumCanvas.setProperties(axisFont=axisFont)
-        
-        self.spectrumCanvas.draw(mspy.plot.container([]))
+        self.spectrumCanvas.draw(self.spectrumContainer)
         
         return self.spectrumCanvas
     # ----
@@ -408,7 +402,7 @@ class panelEnvelopeFit(wx.MiniFrame):
         self.currentFit = None
         
         # check document
-        if not self.currentDocument or not (self.currentDocument.spectrum.hasPoints() or self.currentDocument.spectrum.hasPeaks()):
+        if not self.currentDocument or not (self.currentDocument.spectrum.hasprofile() or self.currentDocument.spectrum.haspeaks()):
             wx.Bell()
             return
         
@@ -487,10 +481,10 @@ class panelEnvelopeFit(wx.MiniFrame):
             self.scaleMax_value.SetValue(str(scale[1]))
         
         # update fitting options
-        if self.currentDocument and not self.currentDocument.spectrum.hasPoints():
+        if self.currentDocument and not self.currentDocument.spectrum.hasprofile():
             self.fitToPeaklist_radio.SetValue(True)
             self.fitToSpectrum_radio.Disable()
-        elif self.currentDocument and not self.currentDocument.spectrum.hasPeaks():
+        elif self.currentDocument and not self.currentDocument.spectrum.haspeaks():
             self.fitToPeaklist_radio.Disable()
             self.fitToSpectrum_radio.SetValue(True)
         else:
@@ -521,20 +515,20 @@ class panelEnvelopeFit(wx.MiniFrame):
             lossCmpd = mspy.compound(loss)
             gainCmpd = mspy.compound(gain)
             
-            config.envfit['loss'] = str(loss)
-            config.envfit['gain'] = str(gain)
+            config.envelopeFit['loss'] = str(loss)
+            config.envelopeFit['gain'] = str(gain)
             
-            config.envfit['fit'] = 'peaklist'
+            config.envelopeFit['fit'] = 'peaklist'
             if self.fitToSpectrum_radio.GetValue():
-                config.envfit['fit'] = 'spectrum'
+                config.envelopeFit['fit'] = 'spectrum'
             
-            config.envfit['charge'] = int(self.charge_value.GetValue())
-            config.envfit['scaleMin'] = int(self.scaleMin_value.GetValue())
-            config.envfit['scaleMax'] = int(self.scaleMax_value.GetValue())
-            config.envfit['fwhm'] = float(self.fwhm_value.GetValue())
-            config.envfit['forceFwhm'] = self.forceFwhm_check.GetValue()
-            config.envfit['autoAlign'] = self.autoAlign_check.GetValue()
-            config.envfit['relThreshold'] = float(self.relThreshold_value.GetValue())/100.
+            config.envelopeFit['charge'] = int(self.charge_value.GetValue())
+            config.envelopeFit['scaleMin'] = int(self.scaleMin_value.GetValue())
+            config.envelopeFit['scaleMax'] = int(self.scaleMax_value.GetValue())
+            config.envelopeFit['fwhm'] = float(self.fwhm_value.GetValue())
+            config.envelopeFit['forceFwhm'] = self.forceFwhm_check.GetValue()
+            config.envelopeFit['autoAlign'] = self.autoAlign_check.GetValue()
+            config.envelopeFit['relThreshold'] = float(self.relThreshold_value.GetValue())/100.
             
             return True
             
@@ -558,26 +552,54 @@ class panelEnvelopeFit(wx.MiniFrame):
     # ----
     
     
+    def updateCanvasProperties(self, refresh=True):
+        """Set current canvas properties."""
+        
+        # set common properties
+        self.spectrumCanvas.setProperties(xLabel=config.spectrum['xLabel'])
+        self.spectrumCanvas.setProperties(yLabel=config.spectrum['yLabel'])
+        self.spectrumCanvas.setProperties(showGrid=config.spectrum['showGrid'])
+        self.spectrumCanvas.setProperties(showMinorTicks=config.spectrum['showMinorTicks'])
+        self.spectrumCanvas.setProperties(intBarHeight=config.spectrum['barHeight'])
+        self.spectrumCanvas.setProperties(xPosDigits=config.main['mzDigits'])
+        self.spectrumCanvas.setProperties(yPosDigits=config.main['intDigits'])
+        self.spectrumCanvas.setProperties(distanceDigits=config.main['mzDigits'])
+        
+        # set font
+        axisFont = wx.Font(config.spectrum['axisFontSize'], wx.SWISS, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL, 0)
+        self.spectrumCanvas.setProperties(axisFont=axisFont)
+        
+        # set cursor
+        cursor = (wx.StockCursor(wx.CURSOR_ARROW), images.lib['cursorsCrossMeasure'])
+        self.spectrumCanvas.setCursorImage(cursor[bool(config.spectrum['showTracker'])])
+        self.spectrumCanvas.setMFunction([None, 'cross'][config.spectrum['showTracker']])
+        
+        # refresh canvas
+        if refresh:
+            self.spectrumCanvas.refresh()
+    # ----
+    
+    
     def updateSpectrumCanvas(self):
         """Update spectrum canvas."""
         
+        # clear container
+        self.spectrumContainer.empty()
+        
         # check fit
         if self.currentFit == None or self.currentFit.error:
-            self.spectrumCanvas.draw(mspy.plot.container([]))
+            self.spectrumCanvas.draw(self.spectrumContainer)
             self.parent.updateTmpSpectrum(None)
             return
         
-        # make container
-        container = mspy.plot.container([])
-        
         # show results
-        container.append(mspy.plot.points(self.currentFit.spectrum, legend='measured', showPoints=False, exactFit=True, lineColour=(16, 71, 185)))
-        container.append(mspy.plot.points(self.currentFit.envelope(), legend='model', showPoints=False, exactFit=True, lineColour=(241,144,0)))
-        container.append(mspy.plot.points(self.currentFit.data, legend='', showLines=False, pointColour=(16, 71, 185)))
-        container.append(mspy.plot.points(self.currentFit.model, legend='', showLines=False, pointColour=(241,144,0)))
+        self.spectrumContainer.append(mspy.plot.points(self.currentFit.spectrum, legend='measured', showPoints=False, exactFit=True, lineColour=(16, 71, 185)))
+        self.spectrumContainer.append(mspy.plot.points(self.currentFit.envelope(), legend='model', showPoints=False, exactFit=True, lineColour=(241,144,0)))
+        self.spectrumContainer.append(mspy.plot.points(self.currentFit.data, legend='', showLines=False, pointColour=(16, 71, 185)))
+        self.spectrumContainer.append(mspy.plot.points(self.currentFit.model, legend='', showLines=False, pointColour=(241,144,0)))
         
         # draw container
-        self.spectrumCanvas.draw(container)
+        self.spectrumCanvas.draw(self.spectrumContainer)
         
         # update spectrum overlay
         self.parent.updateTmpSpectrum(self.currentFit.envelope())
@@ -624,26 +646,27 @@ class panelEnvelopeFit(wx.MiniFrame):
         try:
             
             # init module
-            self.currentFit = mspy.envelopeFit(
+            self.currentFit = mspy.envfit(
                 formula = self.currentCompound.formula(),
-                charge = config.envfit['charge'],
-                scale = (config.envfit['scaleMin'], config.envfit['scaleMax']),
-                loss = config.envfit['loss'],
-                gain = config.envfit['gain']
+                charge = config.envelopeFit['charge'],
+                scale = (config.envelopeFit['scaleMin'], config.envelopeFit['scaleMax']),
+                loss = config.envelopeFit['loss'],
+                gain = config.envelopeFit['gain']
             )
             
             # fit data to peaklist
-            if config.envfit['fit'] == 'peaklist':
-                self.currentFit.fitToPeaklist(
+            if config.envelopeFit['fit'] == 'peaklist':
+                self.currentFit.topeaklist(
                     peaklist = self.currentDocument.spectrum.peaklist,
-                    fwhm = config.envfit['fwhm'],
-                    forceFwhm = config.envfit['forceFwhm'],
-                    autoAlign = config.envfit['autoAlign'],
-                    iterLimit =  100*config.envfit['scaleMax']
+                    fwhm = config.envelopeFit['fwhm'],
+                    forceFwhm = config.envelopeFit['forceFwhm'],
+                    autoAlign = config.envelopeFit['autoAlign'],
+                    iterLimit =  100*config.envelopeFit['scaleMax'],
+                    relThreshold = config.envelopeFit['relThreshold']
                 )
             
             # fit data to spectrum
-            elif config.envfit['fit'] == 'spectrum':
+            elif config.envelopeFit['fit'] == 'spectrum':
                 
                 # get baseline window
                 baselineWindow = 1.
@@ -653,19 +676,18 @@ class panelEnvelopeFit(wx.MiniFrame):
                 # get baseline
                 baseline = self.currentDocument.spectrum.baseline(
                     window = baselineWindow,
-                    smooth = True,
                     offset = config.processing['baseline']['offset']
                 )
                 
                 # fit data to spectrum
-                self.currentFit.fitToSpectrum(
-                    points = self.currentDocument.spectrum.points,
-                    fwhm = config.envfit['fwhm'],
-                    forceFwhm = config.envfit['forceFwhm'],
-                    autoAlign = config.envfit['autoAlign'],
-                    iterLimit =  100*config.envfit['scaleMax'],
+                self.currentFit.tospectrum(
+                    signal = self.currentDocument.spectrum.profile,
+                    fwhm = config.envelopeFit['fwhm'],
+                    forceFwhm = config.envelopeFit['forceFwhm'],
+                    autoAlign = config.envelopeFit['autoAlign'],
+                    iterLimit =  100*config.envelopeFit['scaleMax'],
                     pickingHeight = config.processing['peakpicking']['pickingHeight'],
-                    relThreshold = config.envfit['relThreshold'],
+                    relThreshold = config.envelopeFit['relThreshold'],
                     baselineData = baseline
                 )
             
