@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -115,9 +115,7 @@ class panelMassCalculator(wx.MiniFrame):
         
         # make save button
         self.save_butt = wx.Button(panel, -1, "Save", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.save_butt.SetFont(wx.SMALL_FONT)
         self.save_butt.Bind(wx.EVT_BUTTON, self.onSave)
-        self.save_butt.Enable(False)
         
         # pack elements
         self.toolbar = wx.BoxSizer(wx.HORIZONTAL)
@@ -185,13 +183,13 @@ class panelMassCalculator(wx.MiniFrame):
         # make controls
         ionseriesAgent_label = wx.StaticText(ctrlPanel, -1, "Agent:")
         ionseriesAgent_label.SetFont(wx.SMALL_FONT)
-        self.ionseriesAgentFormula_value = wx.TextCtrl(ctrlPanel, -1, config.masscalc['ionseriesAgent'], size=(60, mwx.SMALL_TEXTCTRL_HEIGHT))
+        self.ionseriesAgentFormula_value = wx.TextCtrl(ctrlPanel, -1, config.massCalculator['ionseriesAgent'], size=(60, mwx.SMALL_TEXTCTRL_HEIGHT))
         self.ionseriesAgentFormula_value.SetFont(wx.SMALL_FONT)
         self.ionseriesAgentFormula_value.Bind(wx.EVT_TEXT, self.onCompoundChanged)
         
         ionseriesAgentCharge_label = wx.StaticText(ctrlPanel, -1, "Agent charge:")
         ionseriesAgentCharge_label.SetFont(wx.SMALL_FONT)
-        self.ionseriesAgentCharge_value = wx.TextCtrl(ctrlPanel, -1, str(config.masscalc['ionseriesAgentCharge']), size=(40, mwx.SMALL_TEXTCTRL_HEIGHT), validator=mwx.validator('int'))
+        self.ionseriesAgentCharge_value = wx.TextCtrl(ctrlPanel, -1, str(config.massCalculator['ionseriesAgentCharge']), size=(40, mwx.SMALL_TEXTCTRL_HEIGHT), validator=mwx.validator('int'))
         self.ionseriesAgentCharge_value.SetFont(wx.SMALL_FONT)
         self.ionseriesAgentCharge_value.Bind(wx.EVT_TEXT, self.onCompoundChanged)
         
@@ -206,7 +204,7 @@ class panelMassCalculator(wx.MiniFrame):
         self.ionseriesNegative_radio.SetFont(wx.SMALL_FONT)
         self.ionseriesNegative_radio.Bind(wx.EVT_RADIOBUTTON, self.onCompoundChanged)
         
-        if config.masscalc['ionseriesPolarity'] == -1:
+        if config.massCalculator['ionseriesPolarity'] == -1:
             self.ionseriesNegative_radio.SetValue(True)
         else:
             self.ionseriesPositive_radio.SetValue(True)
@@ -251,28 +249,33 @@ class panelMassCalculator(wx.MiniFrame):
         
         patternFwhm_label = wx.StaticText(ctrlPanel, -1, "FWHM:")
         patternFwhm_label.SetFont(wx.SMALL_FONT)
-        self.patternFwhm_value = mwx.scrollTextCtrl(ctrlPanel, -1, str(config.masscalc['patternFwhm']), multiplier=0.1, limits=(0.001,10), digits=3, size=(55, mwx.SMALL_TEXTCTRL_HEIGHT))
+        self.patternFwhm_value = mwx.scrollTextCtrl(ctrlPanel, -1, str(config.massCalculator['patternFwhm']), multiplier=0.1, limits=(0.001,10), digits=3, size=(60, mwx.SMALL_TEXTCTRL_HEIGHT))
         self.patternFwhm_value.SetFont(wx.SMALL_FONT)
         self.patternFwhm_value.Bind(wx.EVT_TEXT, self.onPatternChanged)
         
         patternIntensity_label = wx.StaticText(ctrlPanel, -1, "Intensity:")
         patternIntensity_label.SetFont(wx.SMALL_FONT)
-        self.patternIntensity_value = mwx.scrollTextCtrl(ctrlPanel, -1, str(config.masscalc['patternIntensity']), multiplier=0.1, limits=(1,None), size=(70, mwx.SMALL_TEXTCTRL_HEIGHT))
+        self.patternIntensity_value = mwx.scrollTextCtrl(ctrlPanel, -1, str(config.massCalculator['patternIntensity']), multiplier=0.1, limits=(1,None), size=(60, mwx.SMALL_TEXTCTRL_HEIGHT))
         self.patternIntensity_value.SetFont(wx.SMALL_FONT)
         self.patternIntensity_value.Bind(wx.EVT_TEXT, self.onPatternChanged)
         
         patternBaseline_label = wx.StaticText(ctrlPanel, -1, "Baseline:")
         patternBaseline_label.SetFont(wx.SMALL_FONT)
-        self.patternBaseline_value = mwx.scrollTextCtrl(ctrlPanel, -1, str(config.masscalc['patternBaseline']), multiplier=0.1, limits=(0,None), size=(70, mwx.SMALL_TEXTCTRL_HEIGHT))
+        self.patternBaseline_value = mwx.scrollTextCtrl(ctrlPanel, -1, str(config.massCalculator['patternBaseline']), multiplier=0.1, limits=(0,None), size=(60, mwx.SMALL_TEXTCTRL_HEIGHT))
         self.patternBaseline_value.SetFont(wx.SMALL_FONT)
         self.patternBaseline_value.Bind(wx.EVT_TEXT, self.onPatternChanged)
         
         patternShift_label = wx.StaticText(ctrlPanel, -1, "Shift:")
         patternShift_label.SetFont(wx.SMALL_FONT)
-        self.patternShift_value = mwx.scrollTextCtrl(ctrlPanel, -1, "0", step=0.001, digits=3, limits=(-1.,1.), size=(55, mwx.SMALL_TEXTCTRL_HEIGHT))
+        self.patternShift_value = mwx.scrollTextCtrl(ctrlPanel, -1, "0", step=0.001, digits=3, limits=(-1.,1.), size=(60, mwx.SMALL_TEXTCTRL_HEIGHT))
         self.patternShift_value.SetFont(wx.SMALL_FONT)
         self.patternShift_value.Bind(wx.EVT_TEXT, self.onPatternChanged)
         
+        self.showPeaks_check = wx.CheckBox(ctrlPanel, -1, "Show peaks")
+        self.showPeaks_check.SetFont(wx.SMALL_FONT)
+        self.showPeaks_check.SetValue(config.massCalculator['patternShowPeaks'])
+        self.showPeaks_check.Bind(wx.EVT_CHECKBOX, self.onPatternChanged)
+        
         # pack controls
         controls = wx.BoxSizer(wx.HORIZONTAL)
         controls.AddSpacer(mwx.CONTROLBAR_RSPACE)
@@ -289,6 +292,8 @@ class panelMassCalculator(wx.MiniFrame):
         controls.AddSpacer(20)
         controls.Add(patternShift_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
         controls.Add(self.patternShift_value, 0, wx.ALIGN_CENTER_VERTICAL)
+        controls.AddSpacer(20)
+        controls.Add(self.showPeaks_check, 0, wx.ALIGN_CENTER_VERTICAL)
         controls.AddSpacer(mwx.CONTROLBAR_RSPACE)
         controls.Fit(ctrlPanel)
         ctrlPanel.SetSizer(controls)
@@ -338,6 +343,9 @@ class panelMassCalculator(wx.MiniFrame):
         # set default params
         self.patternCanvas.setProperties(xLabel='m/z')
         self.patternCanvas.setProperties(yLabel='a.i.')
+        self.patternCanvas.setProperties(showZero=False)
+        self.patternCanvas.setProperties(showGrid=True)
+        self.patternCanvas.setProperties(showMinorTicks=False)
         self.patternCanvas.setProperties(showLegend=True)
         self.patternCanvas.setProperties(showPosBar=True)
         self.patternCanvas.setProperties(showIntBar=True)
@@ -404,13 +412,11 @@ class panelMassCalculator(wx.MiniFrame):
             self.SetTitle("Compound Summary")
             self.mainSizer.Show(1)
             self.summary_butt.SetBitmapLabel(images.lib['massCalculatorSummaryOn'])
-            self.save_butt.Enable(False)
             
         elif tool == 'ionseries':
             self.SetTitle("Ion Series")
             self.mainSizer.Show(2)
             self.ionseries_butt.SetBitmapLabel(images.lib['massCalculatorIonSeriesOn'])
-            self.save_butt.Enable(False)
             
         elif tool == 'pattern':
             self.SetTitle("Isotopic Pattern")
@@ -419,7 +425,6 @@ class panelMassCalculator(wx.MiniFrame):
             self.toolbar.Show(8)
             self.pattern_butt.SetBitmapLabel(images.lib['massCalculatorPatternOn'])
             self.patternCollapse_butt.SetBitmapLabel(images.lib['arrowsDown'])
-            self.save_butt.Enable(True)
         
         # fit layout
         mwx.layout(self, self.mainSizer)
@@ -552,13 +557,13 @@ class panelMassCalculator(wx.MiniFrame):
         
         # make annotations
         mass = self.currentCompound.mass()
-        mz = self.currentCompound.mz(charge=charge, agentFormula=config.masscalc['ionseriesAgent'], agentCharge=config.masscalc['ionseriesAgentCharge'])
-        document.annotations.append(doc.annotation(label='monoisotopic m/z', mz=mz[0], ai=config.masscalc['patternIntensity'], base=config.masscalc['patternBaseline']))
-        document.annotations.append(doc.annotation(label='average m/z', mz=mz[1], ai=config.masscalc['patternIntensity'], base=config.masscalc['patternBaseline']))
+        mz = self.currentCompound.mz(charge=charge, agentFormula=config.massCalculator['ionseriesAgent'], agentCharge=config.massCalculator['ionseriesAgentCharge'])
+        document.annotations.append(doc.annotation(label='monoisotopic m/z', mz=mz[0], ai=config.massCalculator['patternIntensity'], base=config.massCalculator['patternBaseline']))
+        document.annotations.append(doc.annotation(label='average m/z', mz=mz[1], ai=config.massCalculator['patternIntensity'], base=config.massCalculator['patternBaseline']))
         
         # make notes
         document.notes = 'Theoretical isotopic pattern.\n'
-        document.notes += 'FWHM: %s\n\n' % (config.masscalc['patternFwhm'])
+        document.notes += 'FWHM: %s\n\n' % (config.massCalculator['patternFwhm'])
         document.notes += 'Compound: %s\n' % (self.currentCompound.formula())
         document.notes += 'Monoisotopic mass: %s\n' % (mass[0])
         document.notes += 'Average mass: %s\n\n' % (mass[1])
@@ -599,6 +604,11 @@ class panelMassCalculator(wx.MiniFrame):
             fwhm = min(10, fwhm)
             self.patternFwhm_value.ChangeValue(str(round(fwhm,3)))
         
+        if intensity != None and baseline != None and baseline >= intensity:
+            intensity = 2*baseline
+            if intensity == 0.:
+                intensity = 1.
+        
         if intensity != None:
             intensity = round(intensity)
             if intensity > 10000 or intensity < -10000:
@@ -664,17 +674,18 @@ class panelMassCalculator(wx.MiniFrame):
                 return False
             
             # ionseries
-            config.masscalc['ionseriesAgentCharge'] = int(self.ionseriesAgentCharge_value.GetValue())
+            config.massCalculator['ionseriesAgentCharge'] = int(self.ionseriesAgentCharge_value.GetValue())
             if self.ionseriesNegative_radio.GetValue():
-                config.masscalc['ionseriesPolarity'] = -1
+                config.massCalculator['ionseriesPolarity'] = -1
             else:
-                config.masscalc['ionseriesPolarity'] = 1
+                config.massCalculator['ionseriesPolarity'] = 1
             
             # pattern
             patternFwhm = float(self.patternFwhm_value.GetValue())
             patternIntensity = float(self.patternIntensity_value.GetValue())
             patternBaseline = float(self.patternBaseline_value.GetValue())
             patternShift = float(self.patternShift_value.GetValue())
+            config.massCalculator['patternShowPeaks'] = self.showPeaks_check.GetValue()
         
         except:
             wx.Bell()
@@ -694,12 +705,12 @@ class panelMassCalculator(wx.MiniFrame):
         try:
             if ionseriesAgent != 'e':
                 agent = mspy.compound(ionseriesAgent)
-            config.masscalc['ionseriesAgent'] = ionseriesAgent
+            config.massCalculator['ionseriesAgent'] = ionseriesAgent
         except:
             return False
         
         if ionseriesAgent == 'e':
-            config.masscalc['ionseriesAgentCharge'] = -1
+            config.massCalculator['ionseriesAgentCharge'] = -1
             self.ionseriesAgentCharge_value.ChangeValue('-1')
         
         # check pattern values
@@ -710,10 +721,10 @@ class panelMassCalculator(wx.MiniFrame):
             wx.Bell()
             return False
         else:
-            config.masscalc['patternFwhm'] = patternFwhm
-            config.masscalc['patternIntensity'] = patternIntensity
-            config.masscalc['patternBaseline'] = patternBaseline
-            config.masscalc['patternShift'] = patternShift
+            config.massCalculator['patternFwhm'] = patternFwhm
+            config.massCalculator['patternIntensity'] = patternIntensity
+            config.massCalculator['patternBaseline'] = patternBaseline
+            config.massCalculator['patternShift'] = patternShift
         
         return True
     # ----
@@ -836,7 +847,7 @@ class panelMassCalculator(wx.MiniFrame):
         # draw profile as tmp spectrum
         tmpSpectrum = None
         if self.currentIon != None:
-            tmpSpectrum = self.currentPatternProfile + numpy.array([config.masscalc['patternShift'], 0.0])
+            tmpSpectrum = self.currentPatternProfile + numpy.array([config.massCalculator['patternShift'], 0.0])
         self.parent.updateTmpSpectrum(tmpSpectrum)
     # ----
     
@@ -860,28 +871,28 @@ class panelMassCalculator(wx.MiniFrame):
                 
                 # get charge
                 i += 1
-                charge = i*config.masscalc['ionseriesPolarity']*abs(config.masscalc['ionseriesAgentCharge'])
+                charge = i*config.massCalculator['ionseriesPolarity']*abs(config.massCalculator['ionseriesAgentCharge'])
                 
                 # check ion
-                if not self.currentCompound.isvalid(charge=charge, agentFormula=config.masscalc['ionseriesAgent'], agentCharge=config.masscalc['ionseriesAgentCharge']):
+                if not self.currentCompound.isvalid(charge=charge, agentFormula=config.massCalculator['ionseriesAgent'], agentCharge=config.massCalculator['ionseriesAgentCharge']):
                     break
                 
                 # get ion type
-                if config.masscalc['ionseriesPolarity'] == 1 and config.masscalc['ionseriesAgentCharge'] > 0:
-                    iontype = '[M+%d%s] %d+' % (i, config.masscalc['ionseriesAgent'], abs(charge))
-                elif config.masscalc['ionseriesPolarity'] == 1:
-                    iontype = '[M-%d%s] %d+' % (i, config.masscalc['ionseriesAgent'], abs(charge))
-                elif config.masscalc['ionseriesAgentCharge'] < 0:
-                    iontype = '[M+%d%s] %d-' % (i, config.masscalc['ionseriesAgent'], abs(charge))
+                if config.massCalculator['ionseriesPolarity'] == 1 and config.massCalculator['ionseriesAgentCharge'] > 0:
+                    iontype = '[M+%d%s] %d+' % (i, config.massCalculator['ionseriesAgent'], abs(charge))
+                elif config.massCalculator['ionseriesPolarity'] == 1:
+                    iontype = '[M-%d%s] %d+' % (i, config.massCalculator['ionseriesAgent'], abs(charge))
+                elif config.massCalculator['ionseriesAgentCharge'] < 0:
+                    iontype = '[M+%d%s] %d-' % (i, config.massCalculator['ionseriesAgent'], abs(charge))
                 else:
-                    iontype = '[M-%d%s] %d-' % (i, config.masscalc['ionseriesAgent'], abs(charge))
+                    iontype = '[M-%d%s] %d-' % (i, config.massCalculator['ionseriesAgent'], abs(charge))
                 
                 # get mz
-                mz = mspy.mz(mass, charge=charge, agentFormula=config.masscalc['ionseriesAgent'], agentCharge=config.masscalc['ionseriesAgentCharge'])
+                mz = mspy.mz(mass, charge=charge, agentFormula=config.massCalculator['ionseriesAgent'], agentCharge=config.massCalculator['ionseriesAgentCharge'])
                 
                 # add to list
                 self.currentIons.append((abs(charge), mz[0], mz[1], charge, iontype))
-                if config.masscalc['ionseriesAgent'] == 'e':
+                if config.massCalculator['ionseriesAgent'] == 'e':
                     break
                 
                 # check limits
@@ -912,43 +923,44 @@ class panelMassCalculator(wx.MiniFrame):
             
             # calculate compound pattern
             pattern = self.currentCompound.pattern(
-                fwhm = min(0.9, config.masscalc['patternFwhm']),
-                threshold = config.masscalc['patternThreshold'],
+                fwhm = min(0.9, config.massCalculator['patternFwhm']),
+                threshold = config.massCalculator['patternThreshold'],
                 charge = charge,
-                agentFormula = config.masscalc['ionseriesAgent'],
-                agentCharge = config.masscalc['ionseriesAgentCharge']
+                agentFormula = config.massCalculator['ionseriesAgent'],
+                agentCharge = config.massCalculator['ionseriesAgentCharge']
             )
             
             # make peaklist from pattern
             peaklist = []
             for isotope in pattern:
-                ai = isotope[1]*(config.masscalc['patternIntensity'] - config.masscalc['patternBaseline']) + config.masscalc['patternBaseline']
+                ai = isotope[1]*(config.massCalculator['patternIntensity'] - config.massCalculator['patternBaseline']) + config.massCalculator['patternBaseline']
                 peak = mspy.peak(
                     mz = isotope[0],
                     ai = ai,
-                    base = config.masscalc['patternBaseline'],
-                    fwhm = config.masscalc['patternFwhm'],
+                    base = config.massCalculator['patternBaseline'],
+                    fwhm = config.massCalculator['patternFwhm'],
                     charge = charge
                 )
                 peaklist.append(peak)
             peaklist = mspy.peaklist(peaklist)
             
-            # make peaks
+            # make individual peak shapes
             self.currentPatternPeaks = []
-            for isotope in peaklist:
-                peak = mspy.gaussian(
-                    mz = isotope.mz,
-                    ai = isotope.ai,
-                    base = isotope.base,
-                    fwhm = isotope.fwhm
-                )
-                self.currentPatternPeaks.append(peak)
+            if config.massCalculator['patternShowPeaks']:
+                for isotope in peaklist:
+                    peak = mspy.gaussian(
+                        x = isotope.mz,
+                        minY = isotope.base,
+                        maxY = isotope.ai,
+                        fwhm = isotope.fwhm
+                    )
+                    self.currentPatternPeaks.append(peak)
             
             # make profile spectrum
             self.currentPatternProfile = mspy.profile(peaklist)
             
             # make final spectrum
-            self.currentPatternScan = mspy.scan(points=self.currentPatternProfile, peaks=peaklist)
+            self.currentPatternScan = mspy.scan(profile=self.currentPatternProfile, peaklist=peaklist)
             
         # task canceled
         except mspy.ForceQuit:
