@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -141,11 +141,9 @@ class panelMatch(wx.MiniFrame):
             self.ignoreCharge_check.Disable()
         
         self.match_butt = wx.Button(panel, -1, "Match", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.match_butt.SetFont(wx.SMALL_FONT)
         self.match_butt.Bind(wx.EVT_BUTTON, self.onMatch)
         
         self.calibrate_butt = wx.Button(panel, -1, "Calibrate", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.calibrate_butt.SetFont(wx.SMALL_FONT)
         self.calibrate_butt.Bind(wx.EVT_BUTTON, self.onCalibrate)
         
         # pack elements
@@ -237,6 +235,8 @@ class panelMatch(wx.MiniFrame):
         self.errorCanvas.setProperties(xLabel='m/z')
         self.errorCanvas.setProperties(yLabel='error (%s)' % config.match['units'])
         self.errorCanvas.setProperties(showZero=True)
+        self.errorCanvas.setProperties(showGrid=True)
+        self.errorCanvas.setProperties(showMinorTicks=False)
         self.errorCanvas.setProperties(showLegend=False)
         self.errorCanvas.setProperties(showPosBar=True)
         self.errorCanvas.setProperties(posBarHeight=6)
@@ -260,7 +260,7 @@ class panelMatch(wx.MiniFrame):
         """Make match summary list."""
         
         # init list
-        self.summaryList = mwx.sortListCtrl(self, -1, size=(621, 200), style=mwx.LISTCTRL_STYLE_SINGLE)
+        self.summaryList = mwx.sortListCtrl(self, -1, size=(631, 200), style=mwx.LISTCTRL_STYLE_SINGLE)
         self.summaryList.SetFont(wx.SMALL_FONT)
         self.summaryList.setAltColour(mwx.LISTCTRL_ALTCOLOUR)
         
@@ -269,7 +269,7 @@ class panelMatch(wx.MiniFrame):
         self.summaryList.InsertColumn(1, "value", wx.LIST_FORMAT_LEFT)
         
         # set column widths
-        for col, width in enumerate((250,350)):
+        for col, width in enumerate((250,360)):
             self.summaryList.SetColumnWidth(col, width)
     # ----
     
@@ -663,7 +663,7 @@ class panelMatch(wx.MiniFrame):
         # make peaklist object
         if self.currentPeaklist:
             peaks = self.makeCurrentPeaklist()
-            peaklist = mspy.plot.spectrum(mspy.scan(peaks=peaks), tickColour=(170,170,170), showLabels=False)
+            peaklist = mspy.plot.spectrum(mspy.scan(peaklist=peaks), tickColour=(170,170,170), showLabels=False)
             container.append(peaklist)
         
         # set units
