@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -87,11 +87,11 @@ class panelPeakDifferences(wx.MiniFrame):
         
         self.aminoacids_check = wx.CheckBox(panel, -1, "Amino acids")
         self.aminoacids_check.SetFont(wx.SMALL_FONT)
-        self.aminoacids_check.SetValue(config.differences['aminoacids'])
+        self.aminoacids_check.SetValue(config.peakDifferences['aminoacids'])
         
         self.dipeptides_check = wx.CheckBox(panel, -1, "Dipeptides")
         self.dipeptides_check.SetFont(wx.SMALL_FONT)
-        self.dipeptides_check.SetValue(config.differences['dipeptides'])
+        self.dipeptides_check.SetValue(config.peakDifferences['dipeptides'])
         
         massType_label = wx.StaticText(panel, -1, "Mass:")
         massType_label.SetFont(wx.SMALL_FONT)
@@ -102,18 +102,21 @@ class panelPeakDifferences(wx.MiniFrame):
         
         self.massTypeAv_radio = wx.RadioButton(panel, -1, "Av")
         self.massTypeAv_radio.SetFont(wx.SMALL_FONT)
-        self.massTypeAv_radio.SetValue(config.differences['massType'])
+        self.massTypeAv_radio.SetValue(config.peakDifferences['massType'])
         
         tolerance_label = wx.StaticText(panel, -1, "Tolerance:")
         tolerance_label.SetFont(wx.SMALL_FONT)
         
-        self.tolerance_value = wx.TextCtrl(panel, -1, str(config.differences['tolerance']), size=(50, -1), validator=mwx.validator('floatPos'))
+        self.tolerance_value = wx.TextCtrl(panel, -1, str(config.peakDifferences['tolerance']), size=(50, -1), validator=mwx.validator('floatPos'))
         
         toleranceUnits_label = wx.StaticText(panel, -1, "m/z")
         toleranceUnits_label.SetFont(wx.SMALL_FONT)
         
+        self.showAll_check = wx.CheckBox(panel, -1, "Show full table")
+        self.showAll_check.SetFont(wx.SMALL_FONT)
+        self.showAll_check.SetValue(config.peakDifferences['showAll'])
+        
         self.search_butt = wx.Button(panel, -1, "Search", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.search_butt.SetFont(wx.SMALL_FONT)
         self.search_butt.Bind(wx.EVT_BUTTON, self.onSearch)
         
         # pack elements
@@ -132,6 +135,8 @@ class panelPeakDifferences(wx.MiniFrame):
         sizer.Add(tolerance_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
         sizer.Add(self.tolerance_value, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
         sizer.Add(toleranceUnits_label, 0, wx.ALIGN_CENTER_VERTICAL)
+        sizer.AddSpacer(20)
+        sizer.Add(self.showAll_check, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddStretchSpacer()
         sizer.AddSpacer(20)
         sizer.Add(self.search_butt, 0, wx.ALIGN_CENTER_VERTICAL)
@@ -184,6 +189,7 @@ class panelPeakDifferences(wx.MiniFrame):
         self.differencesGrid.SetDefaultCellBackgroundColour(wx.WHITE)
         
         self.differencesGrid.Bind(wx.grid.EVT_GRID_SELECT_CELL, self.onCellSelected)
+        self.differencesGrid.Bind(wx.grid.EVT_GRID_CELL_LEFT_DCLICK, self.onCellActivated)
     # ----
     
     
@@ -277,6 +283,43 @@ class panelPeakDifferences(wx.MiniFrame):
     # ----
     
     
+    def onCellActivated(self, evt):
+        """Grid cell activated."""
+        
+        evt.Skip()
+        
+        # get cell
+        col = evt.GetCol()
+        row = evt.GetRow()
+        
+        # highlight selected cell
+        self.differencesGrid.SelectBlock(row, col, row, col)
+        
+        # get peaklist
+        peaklist = self.currentDocument.spectrum.peaklist
+        if not peaklist:
+            wx.Bell()
+            return
+        
+        # get peaks and diff
+        mz1 = peaklist[col].mz
+        mz2 = peaklist[row].mz
+        diff = abs(mz1-mz2)
+        
+        # highlight masses in plot
+        self.parent.updateMassPoints([mz1,mz2])
+        
+        # send difference into mass to formula tool
+        self.parent.onToolsMassToFormula(
+            mass = diff,
+            charge = 0,
+            tolerance = config.peakDifferences['tolerance'],
+            units = 'Da',
+            agentFormula = ''
+        )
+    # ----
+    
+    
     def setData(self, document):
         """Set data."""
         
@@ -303,10 +346,11 @@ class panelPeakDifferences(wx.MiniFrame):
             else:
                 self.difference = None
             
-            config.differences['aminoacids'] = int(self.aminoacids_check.GetValue())
-            config.differences['dipeptides'] = int(self.dipeptides_check.GetValue())
-            config.differences['tolerance'] = float(self.tolerance_value.GetValue())
-            config.differences['massType'] = int(self.massTypeAv_radio.GetValue())
+            config.peakDifferences['aminoacids'] = int(self.aminoacids_check.GetValue())
+            config.peakDifferences['dipeptides'] = int(self.dipeptides_check.GetValue())
+            config.peakDifferences['tolerance'] = float(self.tolerance_value.GetValue())
+            config.peakDifferences['massType'] = int(self.massTypeAv_radio.GetValue())
+            config.peakDifferences['showAll'] = int(self.showAll_check.GetValue())
             
             return True
             
@@ -363,7 +407,7 @@ class panelPeakDifferences(wx.MiniFrame):
                     j=x
                 
                 # check limit
-                if self.currentDifferences[i][j][0] > self.currentLimit:
+                if not config.peakDifferences['showAll'] and self.currentDifferences[i][j][0] > self.currentLimit:
                     continue
                 
                 # set value
@@ -436,23 +480,23 @@ class panelPeakDifferences(wx.MiniFrame):
         aaMax = 0
         dipMin = 0
         dipMax = 0
-        if config.differences['aminoacids'] or config.differences['dipeptides']:
+        if config.peakDifferences['aminoacids'] or config.peakDifferences['dipeptides']:
             masses = []
             for aa in aminoacids:
-                masses.append(mspy.monomers[aa].mass[config.differences['massType']])
-            aaMin = min(masses) - config.differences['tolerance']
-            aaMax = max(masses) + config.differences['tolerance']
-            dipMin = min(masses)*2 - config.differences['tolerance']
-            dipMax = max(masses)*2 + config.differences['tolerance']
+                masses.append(mspy.monomers[aa].mass[config.peakDifferences['massType']])
+            aaMin = min(masses) - config.peakDifferences['tolerance']
+            aaMax = max(masses) + config.peakDifferences['tolerance']
+            dipMin = min(masses)*2 - config.peakDifferences['tolerance']
+            dipMax = max(masses)*2 + config.peakDifferences['tolerance']
         
         # get current max
         if self.difference:
-            self.currentLimit = max(aaMin, aaMax, dipMin, dipMax, self.difference+config.differences['tolerance'])
+            self.currentLimit = max(aaMin, aaMax, dipMin, dipMax, self.difference+config.peakDifferences['tolerance'])
         else:
             self.currentLimit = max(aaMin, aaMax, dipMin, dipMax)
         
         # calculate dipeptides
-        if not self.dipeptides and config.differences['dipeptides']:
+        if not self.dipeptides and config.peakDifferences['dipeptides']:
             self.calcDipeptides()
         
         # search
@@ -460,8 +504,8 @@ class panelPeakDifferences(wx.MiniFrame):
             for y in range(len(self.currentDifferences[x])):
                 
                 diff = self.currentDifferences[x][y][0]
-                diffMin = diff - config.differences['tolerance']
-                diffMax = diff + config.differences['tolerance']
+                diffMin = diff - config.peakDifferences['tolerance']
+                diffMax = diff + config.peakDifferences['tolerance']
                 
                 self.currentDifferences[x][y][1] = False
                 matched = False
@@ -472,16 +516,16 @@ class panelPeakDifferences(wx.MiniFrame):
                     matched = True
                 
                 # search for aminoacids
-                if not matched and config.differences['aminoacids'] and aaMin <= diff <= aaMax:
+                if not matched and config.peakDifferences['aminoacids'] and aaMin <= diff <= aaMax:
                     for aa in aminoacids:
-                        if diffMin <= mspy.monomers[aa].mass[config.differences['massType']] <= diffMax:
+                        if diffMin <= mspy.monomers[aa].mass[config.peakDifferences['massType']] <= diffMax:
                             self.currentDifferences[x][y][1] = 'amino'
                             matched = True
                 
                 # search for dipeptides
-                if not matched and config.differences['dipeptides'] and dipMin <= diff <= dipMax:
+                if not matched and config.peakDifferences['dipeptides'] and dipMin <= diff <= dipMax:
                     for dip in self.dipeptides:
-                        if diffMin <= self.dipeptides[dip][config.differences['massType']] <= diffMax:
+                        if diffMin <= self.dipeptides[dip][config.peakDifferences['massType']] <= diffMax:
                             self.currentDifferences[x][y][1] = 'dipep'
                             break
     # ----
@@ -501,21 +545,21 @@ class panelPeakDifferences(wx.MiniFrame):
         # search for value
         if self.difference:
             error = diff - self.difference
-            if abs(error) <= config.differences['tolerance']:
+            if abs(error) <= config.peakDifferences['tolerance']:
                 self.currentMatches.append([str(self.difference), error])
         
         # search for aminoacids
-        if config.differences['aminoacids']:
+        if config.peakDifferences['aminoacids']:
             for aa in aminoacids:
-                error = diff - mspy.monomers[aa].mass[config.differences['massType']]
-                if abs(error) <= config.differences['tolerance']:
+                error = diff - mspy.monomers[aa].mass[config.peakDifferences['massType']]
+                if abs(error) <= config.peakDifferences['tolerance']:
                     self.currentMatches.append([aa, error])
         
         # search for dipeptides
-        if config.differences['dipeptides']:
+        if config.peakDifferences['dipeptides']:
             for dip in self.dipeptides:
-                error = diff - self.dipeptides[dip][config.differences['massType']]
-                if abs(error) <= config.differences['tolerance']:
+                error = diff - self.dipeptides[dip][config.peakDifferences['massType']]
+                if abs(error) <= config.peakDifferences['tolerance']:
                     self.currentMatches.append([dip, error])
     # ----
     
