@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -137,6 +137,11 @@ class panelPeaklist(wx.Panel):
         self.peakList.Bind(wx.EVT_LIST_ITEM_ACTIVATED, self.onItemActivated)
         self.peakList.Bind(wx.EVT_KEY_DOWN, self.onListKey)
         
+        if wx.Platform == '__WXMAC__':
+            self.peakList.Bind(wx.EVT_RIGHT_UP, self.onItemRMU)
+        else:
+            self.peakList.Bind(wx.EVT_LIST_ITEM_RIGHT_CLICK, self.onItemRMU)
+        
         # make columns
         self.makePeakListColumns()
         
@@ -263,11 +268,9 @@ class panelPeaklist(wx.Panel):
         self.peakMonoisotopic_check.SetFont(wx.SMALL_FONT)
         
         self.peakAdd_butt = wx.Button(panel, -1, "Add", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.peakAdd_butt.SetFont(wx.SMALL_FONT)
         self.peakAdd_butt.Bind(wx.EVT_BUTTON, self.onAddPeak)
         
         self.peakReplace_butt = wx.Button(panel, -1, "Update", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.peakReplace_butt.SetFont(wx.SMALL_FONT)
         self.peakReplace_butt.Bind(wx.EVT_BUTTON, self.onReplacePeak)
         self.peakReplace_butt.Enable(False)
         
@@ -331,6 +334,32 @@ class panelPeaklist(wx.Panel):
     # ----
     
     
+    def onItemRMU(self, evt):
+        """Show item pop-up menu."""
+        
+        evt.Skip()
+        
+        # check document and selected peak
+        if self.currentDocument == None or self.selectedPeak == None:
+            return
+        
+        # popup menu
+        menu = wx.Menu()
+        menu.Append(ID_peaklistAnnotate, "Annotate Peak...", "")
+        menu.AppendSeparator()
+        menu.Append(ID_peaklistSendToMassToFormula, "Send to Mass to Formula...", "")
+        
+        # bind events
+        self.Bind(wx.EVT_MENU, self.onAnnotate, id=ID_peaklistAnnotate)
+        self.Bind(wx.EVT_MENU, self.onSendToMassToFormula, id=ID_peaklistSendToMassToFormula)
+        
+        # show menu
+        self.PopupMenu(menu)
+        menu.Destroy()
+        self.SetFocus()
+    # ----
+    
+    
     def onColumnRMU(self, evt):
         """Show column popup menu."""
         
@@ -473,7 +502,7 @@ class panelPeaklist(wx.Panel):
         # add annotation
         self.currentDocument.annotations.append(annot)
         self.currentDocument.sortAnnotations()
-        self.parent.onDocumentChanged(('annotations'))
+        self.parent.onDocumentChanged(items=('annotations'))
     # ----
     
     
@@ -510,7 +539,7 @@ class panelPeaklist(wx.Panel):
         # update data
         self.currentDocument.backup(('spectrum'))
         self.currentDocument.spectrum.peaklist.delete(indexes)
-        self.parent.onDocumentChanged(('spectrum'))
+        self.parent.onDocumentChanged(items=('spectrum'))
     # ---
     
     
@@ -565,7 +594,7 @@ class panelPeaklist(wx.Panel):
             if indexes:
                 self.currentDocument.backup(('spectrum'))
                 self.currentDocument.spectrum.peaklist.delete(indexes)
-                self.parent.onDocumentChanged(('spectrum'))
+                self.parent.onDocumentChanged(items=('spectrum'))
         
         else:
             dlg.Destroy()
@@ -584,7 +613,7 @@ class panelPeaklist(wx.Panel):
         # empty peaklist
         self.currentDocument.backup(('spectrum'))
         self.currentDocument.spectrum.peaklist.empty()
-        self.parent.onDocumentChanged(('spectrum'))
+        self.parent.onDocumentChanged(items=('spectrum'))
     # ----
     
     
@@ -601,7 +630,7 @@ class panelPeaklist(wx.Panel):
         if peak:
             self.currentDocument.backup(('spectrum'))
             self.currentDocument.spectrum.peaklist.append(peak)
-            self.parent.onDocumentChanged(('spectrum'))
+            self.parent.onDocumentChanged(items=('spectrum'))
         
         # set focus to mz
         self.peakMz_value.SetFocus()
@@ -621,7 +650,23 @@ class panelPeaklist(wx.Panel):
         if peak:
             self.currentDocument.backup(('spectrum'))
             self.currentDocument.spectrum.peaklist[self.selectedPeak] = peak
-            self.parent.onDocumentChanged(('spectrum'))
+            self.parent.onDocumentChanged(items=('spectrum'))
+    # ----
+    
+    
+    def onSendToMassToFormula(self, evt=None):
+        """Send selected peak to mass to formula tool."""
+        
+        # check document and selected peak
+        if self.currentDocument == None or self.selectedPeak == None:
+            wx.Bell()
+            return
+        
+        # get peak data
+        peak = self.currentDocument.spectrum.peaklist[self.selectedPeak]
+        
+        # send peak to mass to formula tool
+        self.parent.onToolsMassToFormula(mass=peak.mz, charge=peak.charge)
     # ----
     
     
@@ -979,8 +1024,8 @@ class dlgThreshold(wx.Dialog):
         
         thresholdType_label = wx.StaticText(self, -1, "Threshold type:")
         choices=['m/z', 'a.i.', 'Intensity', 'Relative Intensity', 's/n']
-        self.thresholdType_combo = wx.ComboBox(self, -1, choices=choices, size=(150, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.thresholdType_combo.Select(0)
+        self.thresholdType_choice = wx.Choice(self, -1, choices=choices, size=(150, mwx.CHOICE_HEIGHT))
+        self.thresholdType_choice.Select(0)
         
         cancel_butt = wx.Button(self, wx.ID_CANCEL, "Cancel")
         delete_butt = wx.Button(self, wx.ID_OK, "Delete")
@@ -992,7 +1037,7 @@ class dlgThreshold(wx.Dialog):
         grid.Add(threshold_label, (0,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         grid.Add(self.threshold_value, (0,1))
         grid.Add(thresholdType_label, (1,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        grid.Add(self.thresholdType_combo, (1,1))
+        grid.Add(self.thresholdType_choice, (1,1))
         
         staticSizer.Add(grid, 0, wx.ALL, 5)
         
@@ -1032,7 +1077,7 @@ class dlgThreshold(wx.Dialog):
     
     def getData(self):
         """Return values."""
-        return self.threshold, self.thresholdType_combo.GetValue()
+        return self.threshold, self.thresholdType_choice.GetStringSelection()
     # ----
     
     
@@ -1163,15 +1208,15 @@ class dlgCopy(wx.Dialog):
 class fileDropTarget(wx.FileDropTarget):
     """Generic drop target for files."""
     
-    def __init__(self, fce):
+    def __init__(self, fn):
         wx.FileDropTarget.__init__(self)
-        self.fce = fce
+        self.fn = fn
     # ----
     
     
     def OnDropFiles(self, x, y, paths):
         """Open dropped files."""
-        self.fce(paths=paths)
+        self.fn(paths=paths)
     # ----
     
 
