@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -93,6 +93,7 @@ class panelSpectrum(wx.Panel):
         self.spectrumCanvas.setProperties(yLabel=config.spectrum['yLabel'])
         self.spectrumCanvas.setProperties(showZero=True)
         self.spectrumCanvas.setProperties(showGrid=config.spectrum['showGrid'])
+        self.spectrumCanvas.setProperties(showMinorTicks=config.spectrum['showMinorTicks'])
         self.spectrumCanvas.setProperties(showLegend=config.spectrum['showLegend'])
         self.spectrumCanvas.setProperties(showPosBar=config.spectrum['showPosBars'])
         self.spectrumCanvas.setProperties(showIntBar=config.spectrum['showPosBars'])
@@ -198,7 +199,7 @@ class panelSpectrum(wx.Panel):
         self.toolsDeleteLabel_butt.Bind(wx.EVT_BUTTON, self.parent.onToolsSpectrum)
         
         self.toolsMeasure_butt = wx.BitmapButton(panel, ID_toolsMeasure, images.lib['spectrumMeasureOff'], size=(mwx.BOTTOMBAR_TOOLSIZE), style=wx.BORDER_NONE)
-        self.toolsMeasure_butt.SetToolTip(wx.ToolTip("Measure distances"))
+        self.toolsMeasure_butt.SetToolTip(wx.ToolTip("Spectrum ruler"))
         self.toolsMeasure_butt.Bind(wx.EVT_BUTTON, self.parent.onToolsSpectrum)
         
         self.toolsOffset_butt = wx.BitmapButton(panel, ID_toolsOffset, images.lib['spectrumOffsetOff'], size=(mwx.BOTTOMBAR_TOOLSIZE), style=wx.BORDER_NONE)
@@ -208,6 +209,7 @@ class panelSpectrum(wx.Panel):
         # make cursor info
         self.cursorInfo = wx.StaticText(panel, -1, "")
         self.cursorInfo.SetFont(wx.SMALL_FONT)
+        self.cursorInfo.Bind(wx.EVT_RIGHT_UP, self.onCursorInfoRMU)
         
         # pack elements
         sizer = wx.BoxSizer(wx.HORIZONTAL)
@@ -261,7 +263,7 @@ class panelSpectrum(wx.Panel):
     
     
     def onCanvasLMU(self, evt):
-        """Process selected mouse fce."""
+        """Process selected mouse function."""
         
         # check document
         if self.currentDocument == None:
@@ -343,6 +345,40 @@ class panelSpectrum(wx.Panel):
     # ----
     
     
+    def onCursorInfoRMU(self, evt):
+        """Set items to show in cursor info."""
+        
+        # only while active spectrum ruler
+        if self.currentTool != 'measure':
+            return
+        
+        # popup menu
+        menu = wx.Menu()
+        menu.Append(ID_viewSpectrumRulerMz, "m/z", "", wx.ITEM_CHECK)
+        menu.Append(ID_viewSpectrumRulerDist, "Distance", "", wx.ITEM_CHECK)
+        menu.Append(ID_viewSpectrumRulerPpm, "ppm", "", wx.ITEM_CHECK)
+        menu.Append(ID_viewSpectrumRulerZ, "Charge", "", wx.ITEM_CHECK)
+        menu.Append(ID_viewSpectrumRulerArea, "Area", "", wx.ITEM_CHECK)
+        
+        # set values
+        menu.Check(ID_viewSpectrumRulerMz, bool('mz' in config.main['cursorInfo']))
+        menu.Check(ID_viewSpectrumRulerDist, bool('dist' in config.main['cursorInfo']))
+        menu.Check(ID_viewSpectrumRulerPpm, bool('ppm' in config.main['cursorInfo']))
+        menu.Check(ID_viewSpectrumRulerZ, bool('z' in config.main['cursorInfo']))
+        menu.Check(ID_viewSpectrumRulerArea, bool('area' in config.main['cursorInfo']))
+        
+        # set events
+        self.Bind(wx.EVT_MENU, self.parent.onViewCursorInfo, id=ID_viewSpectrumRulerMz)
+        self.Bind(wx.EVT_MENU, self.parent.onViewCursorInfo, id=ID_viewSpectrumRulerDist)
+        self.Bind(wx.EVT_MENU, self.parent.onViewCursorInfo, id=ID_viewSpectrumRulerPpm)
+        self.Bind(wx.EVT_MENU, self.parent.onViewCursorInfo, id=ID_viewSpectrumRulerZ)
+        self.Bind(wx.EVT_MENU, self.parent.onViewCursorInfo, id=ID_viewSpectrumRulerArea)
+        
+        self.PopupMenu(menu)
+        menu.Destroy()
+    # ----
+    
+    
     def setCurrentTool(self, tool):
         """Slect spectrum tool."""
         
@@ -433,6 +469,7 @@ class panelSpectrum(wx.Panel):
         
         spectrum.setProperties(labelAngle=config.spectrum['labelAngle'])
         spectrum.setProperties(labelCharge=config.spectrum['labelCharge'])
+        spectrum.setProperties(labelGroup=config.spectrum['labelGroup'])
         spectrum.setProperties(labelDigits=config.main['mzDigits'])
         spectrum.setProperties(labelBgr=config.spectrum['labelBgr'])
         spectrum.setProperties(isotopeColour=None)
@@ -502,6 +539,7 @@ class panelSpectrum(wx.Panel):
         self.spectrumCanvas.setProperties(intBarHeight=config.spectrum['barHeight'])
         self.spectrumCanvas.setProperties(showLegend=config.spectrum['showLegend'])
         self.spectrumCanvas.setProperties(showGrid=config.spectrum['showGrid'])
+        self.spectrumCanvas.setProperties(showMinorTicks=config.spectrum['showMinorTicks'])
         
         # set y-axis label
         self.spectrumCanvas.setProperties(yLabel=config.spectrum['yLabel'])
@@ -535,21 +573,28 @@ class panelSpectrum(wx.Panel):
         
         label = ''
         
-        # get polarity
+        # get spectrum polarity
         polarity = 1
         if self.currentDocument != None and self.documents[self.currentDocument].spectrum.polarity == -1:
             polarity = -1
+            return
         
-        # get values
+        # get baseline window (for area calculation)
+        baselineWindow = 1.
+        if config.processing['peakpicking']['baseline']:
+            baselineWindow = 1./config.processing['baseline']['precision']
+        
+        # get basic values
         position = self.spectrumCanvas.getCursorPosition()
         distance = self.spectrumCanvas.getDistance()
-        charge = self.spectrumCanvas.getCharge()
         
         # format numbers
         mzFormat = '%0.' + `config.main['mzDigits']` + 'f'
         intFormat = '%0.' + `config.main['intDigits']` + 'f'
+        distFormat = '%0.' + `config.main['mzDigits']` + 'f'
         ppmFormat = '%0.' + `config.main['ppmDigits']` + 'f'
-        chargeFormat = '%d'
+        areaFormat = '%0.' + `config.main['intDigits']` + 'f'
+        chargeFormat = '%0.1f'
         
         if position and abs(position[1]) > 10000:
             intFormat = '%.2e'
@@ -561,23 +606,54 @@ class panelSpectrum(wx.Panel):
         
         # isotope ruler
         elif self.currentTool == 'labelenvelope' and position:
+            charge = self.spectrumCanvas.getCharge()
             mass = mspy.mz(position[0], charge=0, currentCharge=charge*polarity)
-            format = 'm/z: %s   mass: %s   z: %s' % (mzFormat, mzFormat, chargeFormat)
+            format = 'm/z: %s   mass: %s   z: %s' % (mzFormat, mzFormat, '%d')
             label = format % (position[0], mass, charge*polarity)
         
         # distance measurement
         elif distance and position:
-            charge = 0
-            if distance[0]:
-                charge = int(abs(round(1/distance[0],0)))
-            format = 'm/z: %s   dist: %s   ppm: %s   z: %s' % (mzFormat, mzFormat, ppmFormat, chargeFormat)
-            label += format % (position[0], distance[0], 1e6*distance[0]/position[0], charge*polarity)
+            
+            if 'mz' in config.main['cursorInfo']:
+                format = 'm/z: %s   ' % mzFormat
+                label += format % position[0]
+            
+            if 'dist' in config.main['cursorInfo']:
+                format = 'dist: %s   ' % distFormat
+                label += format % distance[0]
+            
+            if 'ppm' in config.main['cursorInfo']:
+                format = 'ppm: %s   ' % ppmFormat
+                label += format % (1e6*distance[0]/position[0])
+            
+            if 'z' in config.main['cursorInfo'] and distance[0]:
+                if abs(distance[0]) > 10:
+                    charge = abs((min(position[0], position[0]-distance[0]) - 1.00728) / distance[0])
+                    format = 'z: %s/%s   ' % (chargeFormat, chargeFormat)
+                    label += format % ((charge+1)*polarity, charge*polarity)
+                else:
+                    charge = abs(1/distance[0])
+                    format = 'z: %s   ' % chargeFormat
+                    label += format % (charge*polarity)
+            
+            if 'area' in config.main['cursorInfo'] and self.currentDocument != None:
+                area = self.documents[self.currentDocument].spectrum.area(
+                    minX = position[0]-distance[0],
+                    maxX = position[0],
+                    baselineWindow = baselineWindow,
+                    baselineOffset = config.processing['baseline']['offset']
+                )
+                format = 'area: %s   ' % areaFormat
+                label += format % area
         
-        # no specific fce
+        # no specific function
         elif position:
             format = 'm/z: %s   a.i.: %s' % (mzFormat, intFormat)
             label = format % (position[0], position[1])
         
+        # ensure label size to enable popup menu
+        label += ' ' * (100 - len(label))
+        
         # show info
         self.cursorInfo.SetLabel(label)
     # ----
@@ -815,7 +891,7 @@ class panelSpectrum(wx.Panel):
         """Label peak in selection."""
         
         # check document
-        if self.currentDocument == None or not self.documents[self.currentDocument].spectrum.hasPoints():
+        if self.currentDocument == None or not self.documents[self.currentDocument].spectrum.hasprofile():
             return
         
         # get baseline window
@@ -826,29 +902,28 @@ class panelSpectrum(wx.Panel):
         # get baseline
         baseline = self.documents[self.currentDocument].spectrum.baseline(
             window = baselineWindow,
-            smooth = True,
             offset = config.processing['baseline']['offset']
         )
         
         # label peak
-        peak = mspy.labelPeak(
-            points = self.documents[self.currentDocument].spectrum.points,
+        peak = mspy.labelpeak(
+            signal = self.documents[self.currentDocument].spectrum.profile,
             minX = selection[0],
             maxX = selection[2],
             pickingHeight = config.processing['peakpicking']['pickingHeight'],
-            baselineData = baseline
+            baseline = baseline
         )
         
         if peak:
             
             # set as monoisotopic
             if config.processing['deisotoping']['setAsMonoisotopic']:
-                peak.setIsotope(0)
+                peak.setisotope(0)
             
             # update document
             self.documents[self.currentDocument].backup(('spectrum'))
             self.documents[self.currentDocument].spectrum.peaklist.append(peak)
-            self.parent.onDocumentChanged(('spectrum'))
+            self.parent.onDocumentChanged(items=('spectrum'))
     # ----
     
     
@@ -856,7 +931,7 @@ class panelSpectrum(wx.Panel):
         """Label point at position."""
         
         # check document
-        if self.currentDocument == None or not self.documents[self.currentDocument].spectrum.hasPoints():
+        if self.currentDocument == None or not self.documents[self.currentDocument].spectrum.hasprofile():
             return
         
         # get baseline window
@@ -867,27 +942,26 @@ class panelSpectrum(wx.Panel):
         # get baseline
         baseline = self.documents[self.currentDocument].spectrum.baseline(
             window = baselineWindow,
-            smooth = True,
             offset = config.processing['baseline']['offset']
         )
         
         # label point
-        peak = mspy.labelPoint(
-            points = self.documents[self.currentDocument].spectrum.points,
+        peak = mspy.labelpoint(
+            signal = self.documents[self.currentDocument].spectrum.profile,
             mz = mz,
-            baselineData = baseline
+            baseline = baseline
         )
         
         if peak:
             
             # set as monoisotopic
             if config.processing['deisotoping']['setAsMonoisotopic']:
-                peak.setIsotope(0)
+                peak.setisotope(0)
             
             # update document
             self.documents[self.currentDocument].backup(('spectrum'))
             self.documents[self.currentDocument].spectrum.peaklist.append(peak)
-            self.parent.onDocumentChanged(('spectrum'))
+            self.parent.onDocumentChanged(items=('spectrum'))
     # ----
     
     
@@ -895,7 +969,7 @@ class panelSpectrum(wx.Panel):
         """Label isotopes."""
         
         # check document
-        if self.currentDocument == None or not self.documents[self.currentDocument].spectrum.hasPoints():
+        if self.currentDocument == None or not self.documents[self.currentDocument].spectrum.hasprofile():
             return
         
         # get baseline window
@@ -906,7 +980,6 @@ class panelSpectrum(wx.Panel):
         # get baseline
         baseline = self.documents[self.currentDocument].spectrum.baseline(
             window = baselineWindow,
-            smooth = True,
             offset = config.processing['baseline']['offset']
         )
         
@@ -914,11 +987,11 @@ class panelSpectrum(wx.Panel):
         peaks = []
         buff = []
         for isotope in isotopes:
-            peak = mspy.labelPeak(
-                points = self.documents[self.currentDocument].spectrum.points,
+            peak = mspy.labelpeak(
+                signal = self.documents[self.currentDocument].spectrum.profile,
                 mz = isotope,
                 pickingHeight = config.processing['peakpicking']['pickingHeight'],
-                baselineData = baseline
+                baseline = baseline
             )
             if peak and not peak.mz in buff:
                 peaks.append(peak)
@@ -974,29 +1047,29 @@ class panelSpectrum(wx.Panel):
         
         # label monoisotopic peak
         elif config.processing['deisotoping']['labelEnvelope'] == 'monoisotope':
-            peak = mspy.envelopeMonoisotope(peaks, charge=charge*polarity, intensity=config.processing['deisotoping']['envelopeIntensity'])
+            peak = mspy.envmono(peaks, charge=charge*polarity, intensity=config.processing['deisotoping']['envelopeIntensity'])
             if peak:
-                peak.setCharge(charge*polarity)
+                peak.setcharge(charge*polarity)
                 self.documents[self.currentDocument].spectrum.peaklist.append(peak)
         
         # label envelope centroid
         elif config.processing['deisotoping']['labelEnvelope'] == 'centroid':
-            peak = mspy.envelopeCentroid(peaks, height=0.5, intensity=config.processing['deisotoping']['envelopeIntensity'])
+            peak = mspy.envcentroid(peaks, pickingHeight=0.5, intensity=config.processing['deisotoping']['envelopeIntensity'])
             if peak:
-                peak.setCharge(charge*polarity)
+                peak.setcharge(charge*polarity)
                 self.documents[self.currentDocument].spectrum.peaklist.append(peak)
         
         # label all isotopes
         if config.processing['deisotoping']['labelEnvelope'] == 'isotopes':
-            groupname = self.documents[self.currentDocument].spectrum.peaklist.nextGroupName()
+            groupname = self.documents[self.currentDocument].spectrum.peaklist.groupname()
             for x, peak in enumerate(peaks):
-                peak.setIsotope(x)
-                peak.setCharge(charge*polarity)
-                peak.setGroup(groupname)
+                peak.setisotope(x)
+                peak.setcharge(charge*polarity)
+                peak.setgroup(groupname)
                 self.documents[self.currentDocument].spectrum.peaklist.append(peak)
         
         # update gui
-        self.parent.onDocumentChanged(('spectrum'))
+        self.parent.onDocumentChanged(items=('spectrum'))
     # ----
     
     
@@ -1017,7 +1090,7 @@ class panelSpectrum(wx.Panel):
         if indexes:
             self.documents[self.currentDocument].backup(('spectrum'))
             self.documents[self.currentDocument].spectrum.peaklist.delete(indexes)
-            self.parent.onDocumentChanged(('spectrum'))
+            self.parent.onDocumentChanged(items=('spectrum'))
     # ----
     
     
@@ -1059,11 +1132,11 @@ class panelSpectrum(wx.Panel):
 class dlgCanvasProperties(wx.Dialog):
     """Set canvas properties."""
     
-    def __init__(self, parent, onChangeFce):
+    def __init__(self, parent, onChangeFn):
         
         # initialize document frame
         wx.Dialog.__init__(self, parent, -1, "Canvas Properties", style=wx.DEFAULT_DIALOG_STYLE|wx.STAY_ON_TOP)
-        self.onChangeFce = onChangeFce
+        self.onChangeFn = onChangeFn
         
         # make GUI
         sizer = self.makeGUI()
@@ -1153,7 +1226,7 @@ class dlgCanvasProperties(wx.Dialog):
         config.spectrum['notationMaxLength'] = self.notationMaxLength_slider.GetValue()
         
         # set params to canvas and update
-        self.onChangeFce()
+        self.onChangeFn()
     # ----
     
     
@@ -1324,15 +1397,15 @@ class dlgSpectrumOffset(wx.Dialog):
 class fileDropTarget(wx.FileDropTarget):
     """Generic drop target for files."""
     
-    def __init__(self, fce):
+    def __init__(self, fn):
         wx.FileDropTarget.__init__(self)
-        self.fce = fce
+        self.fn = fn
     # ----
     
     
     def OnDropFiles(self, x, y, paths):
         """Open dropped files."""
-        self.fce(paths=paths)
+        self.fn(paths=paths)
     # ----
     
 
