@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -90,28 +90,26 @@ class panelSpectrumGenerator(wx.MiniFrame):
         panel = mwx.bgrPanel(self, -1, images.lib['bgrToolbar'], size=(-1, mwx.TOOLBAR_HEIGHT))
         
         # make elements
-        fwhm_label = wx.StaticText(panel, -1, "FWHM:")
+        fwhm_label = wx.StaticText(panel, -1, "Default FWHM:")
         fwhm_label.SetFont(wx.SMALL_FONT)
-        self.fwhm_value = wx.TextCtrl(panel, -1, str(config.generator['fwhm']), size=(60, -1), validator=mwx.validator('floatPos'))
+        self.fwhm_value = wx.TextCtrl(panel, -1, str(config.spectrumGenerator['fwhm']), size=(60, -1), validator=mwx.validator('floatPos'))
         
         self.forceFwhm_check = wx.CheckBox(panel, -1, "Force")
         self.forceFwhm_check.SetFont(wx.SMALL_FONT)
-        self.forceFwhm_check.SetValue(config.generator['forceFwhm'])
+        self.forceFwhm_check.SetValue(config.spectrumGenerator['forceFwhm'])
         
         points_label = wx.StaticText(panel, -1, "Points per peak:")
         points_label.SetFont(wx.SMALL_FONT)
-        self.points_value = wx.TextCtrl(panel, -1, str(config.generator['points']), size=(60, -1), validator=mwx.validator('intPos'))
+        self.points_value = wx.TextCtrl(panel, -1, str(config.spectrumGenerator['points']), size=(60, -1), validator=mwx.validator('intPos'))
         
         noise_label = wx.StaticText(panel, -1, "Noise width:")
         noise_label.SetFont(wx.SMALL_FONT)
-        self.noise_value = wx.TextCtrl(panel, -1, str(config.generator['noise']), size=(80, -1), validator=mwx.validator('floatPos'))
+        self.noise_value = wx.TextCtrl(panel, -1, str(config.spectrumGenerator['noise']), size=(80, -1), validator=mwx.validator('floatPos'))
         
         self.generate_butt = wx.Button(panel, -1, "Generate", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.generate_butt.SetFont(wx.SMALL_FONT)
         self.generate_butt.Bind(wx.EVT_BUTTON, self.onGenerate)
         
         self.apply_butt = wx.Button(panel, -1, "Apply", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.apply_butt.SetFont(wx.SMALL_FONT)
         self.apply_butt.Bind(wx.EVT_BUTTON, self.onApply)
         
         # pack elements
@@ -152,19 +150,19 @@ class panelSpectrumGenerator(wx.MiniFrame):
         self.collapse_butt = wx.BitmapButton(panel, -1, images.lib['arrowsDown'], size=(mwx.TOOLBAR_TOOLSIZE), style=wx.BORDER_NONE)
         self.collapse_butt.Bind(wx.EVT_BUTTON, self.onCollapse)
         
-        self.showPeaks_check = wx.CheckBox(panel, -1, "Show individual peaks")
+        self.showPeaks_check = wx.CheckBox(panel, -1, "Show peaks")
         self.showPeaks_check.SetFont(wx.SMALL_FONT)
-        self.showPeaks_check.SetValue(config.generator['showPeaks'])
+        self.showPeaks_check.SetValue(config.spectrumGenerator['showPeaks'])
         self.showPeaks_check.Bind(wx.EVT_CHECKBOX, self.onShowPeaks)
         
-        self.showOverlay_check = wx.CheckBox(panel, -1, "Show in main window")
+        self.showOverlay_check = wx.CheckBox(panel, -1, "Show overlay")
         self.showOverlay_check.SetFont(wx.SMALL_FONT)
-        self.showOverlay_check.SetValue(config.generator['showOverlay'])
+        self.showOverlay_check.SetValue(config.spectrumGenerator['showOverlay'])
         self.showOverlay_check.Bind(wx.EVT_CHECKBOX, self.onShowOverlay)
         
-        self.showFlipped_check = wx.CheckBox(panel, -1, "Show flipped")
+        self.showFlipped_check = wx.CheckBox(panel, -1, "Flip overlay")
         self.showFlipped_check.SetFont(wx.SMALL_FONT)
-        self.showFlipped_check.SetValue(config.generator['showFlipped'])
+        self.showFlipped_check.SetValue(config.spectrumGenerator['showFlipped'])
         self.showFlipped_check.Bind(wx.EVT_CHECKBOX, self.onShowFlipped)
         
         # pack elements
@@ -192,8 +190,7 @@ class panelSpectrumGenerator(wx.MiniFrame):
         """Make plot canvas and set defalt parameters."""
         
         # init canvas
-        self.spectrumCanvas = mspy.plot.canvas(self, size=(700, 400), style=mwx.PLOTCANVAS_STYLE_PANEL)
-        self.spectrumCanvas.draw(mspy.plot.container([]))
+        self.spectrumCanvas = mspy.plot.canvas(self, size=(700, 350), style=mwx.PLOTCANVAS_STYLE_PANEL)
         
         # set default params
         self.updateCanvasProperties(refresh=False)
@@ -208,7 +205,7 @@ class panelSpectrumGenerator(wx.MiniFrame):
         
         self.spectrumCanvas.setLMBFunction('xDistance')
         
-        self.spectrumCanvas.draw(mspy.plot.container([]))
+        self.spectrumCanvas.draw(self.spectrumContainer)
         
         return self.spectrumCanvas
     # ----
@@ -345,9 +342,9 @@ class panelSpectrumGenerator(wx.MiniFrame):
             return
         
         # ask to owerwrite spectrum
-        if self.currentDocument.spectrum.hasPoints():
+        if self.currentDocument.spectrum.hasprofile():
             title = 'Do you really want to apply generated spectrum\nto current document?'
-            message = 'Previous spectrum points will be lost.'
+            message = 'Original profile data will be lost.'
             buttons = [(wx.ID_CANCEL, "Cancel", 80, False, 15), (wx.ID_OK, "Apply", 80, True, 0)]
             dlg = mwx.dlgMessage(self, title, message, buttons)
             if dlg.ShowModal() != wx.ID_OK:
@@ -361,10 +358,10 @@ class panelSpectrumGenerator(wx.MiniFrame):
         
         # set profile to document
         points = self.currentProfile.copy()
-        self.currentDocument.spectrum.setPoints(points)
+        self.currentDocument.spectrum.setprofile(points)
         
         # update document
-        self.parent.onDocumentChanged(('spectrum'))
+        self.parent.onDocumentChanged(items=('spectrum'))
     # ----
     
     
@@ -391,7 +388,7 @@ class panelSpectrumGenerator(wx.MiniFrame):
         """Show / hide individual peaks."""
         
         # get value
-        config.generator['showPeaks'] = self.showPeaks_check.GetValue()
+        config.spectrumGenerator['showPeaks'] = self.showPeaks_check.GetValue()
         
         # update spectrum canvas
         self.updateSpectrumCanvas(rescale=False)
@@ -402,7 +399,7 @@ class panelSpectrumGenerator(wx.MiniFrame):
         """Show / hide profile overlay in main viewer."""
         
         # get value
-        config.generator['showOverlay'] = self.showOverlay_check.GetValue()
+        config.spectrumGenerator['showOverlay'] = self.showOverlay_check.GetValue()
         
         # update tmp spectrum
         self.updateSpectrumOverlay()
@@ -413,7 +410,7 @@ class panelSpectrumGenerator(wx.MiniFrame):
         """Flip profile overlay in main viewer."""
         
         # get value
-        config.generator['showFlipped'] = self.showFlipped_check.GetValue()
+        config.spectrumGenerator['showFlipped'] = self.showFlipped_check.GetValue()
         
         # update tmp spectrum
         self.updateSpectrumOverlay()
@@ -439,10 +436,10 @@ class panelSpectrumGenerator(wx.MiniFrame):
         
         # try to get values
         try:
-            config.generator['fwhm'] = abs(float(self.fwhm_value.GetValue()))
-            config.generator['points'] = abs(int(self.points_value.GetValue()))
-            config.generator['noise'] = abs(float(self.noise_value.GetValue()))
-            config.generator['forceFwhm'] = self.forceFwhm_check.GetValue()
+            config.spectrumGenerator['fwhm'] = abs(float(self.fwhm_value.GetValue()))
+            config.spectrumGenerator['points'] = abs(int(self.points_value.GetValue()))
+            config.spectrumGenerator['noise'] = abs(float(self.noise_value.GetValue()))
+            config.spectrumGenerator['forceFwhm'] = self.forceFwhm_check.GetValue()
             return True
             
         except:
@@ -458,6 +455,7 @@ class panelSpectrumGenerator(wx.MiniFrame):
         self.spectrumCanvas.setProperties(xLabel=config.spectrum['xLabel'])
         self.spectrumCanvas.setProperties(yLabel=config.spectrum['yLabel'])
         self.spectrumCanvas.setProperties(showGrid=config.spectrum['showGrid'])
+        self.spectrumCanvas.setProperties(showMinorTicks=config.spectrum['showMinorTicks'])
         self.spectrumCanvas.setProperties(showPosBar=config.spectrum['showPosBars'])
         self.spectrumCanvas.setProperties(showIntBar=config.spectrum['showPosBars'])
         self.spectrumCanvas.setProperties(posBarHeight=config.spectrum['barHeight'])
@@ -514,7 +512,7 @@ class panelSpectrumGenerator(wx.MiniFrame):
         # add main profile spectrum to container
         labelFont = wx.Font(config.spectrum['labelFontSize'], wx.SWISS, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL, 0)
         spectrum = mspy.plot.spectrum(
-            scan = mspy.scan(points=profile, peaks=peaklist),
+            scan = mspy.scan(profile=profile, peaklist=peaklist),
             spectrumColour = (16,71,185),
             tickColour = (255,0,0),
             showPoints = config.spectrum['showDataPoints'],
@@ -528,7 +526,7 @@ class panelSpectrumGenerator(wx.MiniFrame):
         self.spectrumContainer.append(spectrum)
         
         # add individual peaks to container
-        if config.generator['showPeaks']:
+        if config.spectrumGenerator['showPeaks']:
             if self.currentPeaks != None:
                 for peak in self.currentPeaks:
                     spectrum = mspy.plot.points(
@@ -557,10 +555,10 @@ class panelSpectrumGenerator(wx.MiniFrame):
         """Show / hide profile overlay in main viewer."""
         
         # update tmp spectrum
-        if self.currentProfile == None or not config.generator['showOverlay']:
+        if self.currentProfile == None or not config.spectrumGenerator['showOverlay']:
             self.parent.updateTmpSpectrum(None)
         else:
-            self.parent.updateTmpSpectrum(self.currentProfile, flipped=config.generator['showFlipped'])
+            self.parent.updateTmpSpectrum(self.currentProfile, flipped=config.spectrumGenerator['showFlipped'])
     # ----
     
     
@@ -576,10 +574,10 @@ class panelSpectrumGenerator(wx.MiniFrame):
             # make profile spectrum
             self.currentProfile = mspy.profile(
                 peaklist = self.currentDocument.spectrum.peaklist,
-                fwhm = config.generator['fwhm'],
-                points = config.generator['points'],
-                noise = config.generator['noise'],
-                forceFwhm = config.generator['forceFwhm']
+                fwhm = config.spectrumGenerator['fwhm'],
+                points = config.spectrumGenerator['points'],
+                noise = config.spectrumGenerator['noise'],
+                forceFwhm = config.spectrumGenerator['forceFwhm']
             )
             
             # make peak spectra
@@ -587,15 +585,15 @@ class panelSpectrumGenerator(wx.MiniFrame):
             for peak in self.currentDocument.spectrum.peaklist:
                 
                 # get fwhm
-                fwhm = config.generator['fwhm']
-                if peak.fwhm and not config.generator['forceFwhm']:
+                fwhm = config.spectrumGenerator['fwhm']
+                if peak.fwhm and not config.spectrumGenerator['forceFwhm']:
                     fwhm = peak.fwhm
                 
                 # calc peak
                 points = mspy.gaussian(
-                    mz = peak.mz,
-                    ai = peak.ai,
-                    base = peak.base,
+                    x = peak.mz,
+                    minY = peak.base,
+                    maxY = peak.ai,
                     fwhm = fwhm
                 )
                 self.currentPeaks.append(points)
