@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load main config and libs
@@ -69,7 +69,9 @@ class mMass(wx.App):
     
     def MacOpenFile(self, path):
         """"Enable drag/drop under Mac."""
-        self.frame.onDocumentOpen(path=path)
+        
+        if path != 'mmass.py':
+            self.frame.onDocumentOpen(path=path)
     # ----
     
     
