@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,21 +12,34 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
-# register basic objects
-from stopper import *
+# load stopper
+from mod_stopper import *
+
+# load building blocks
 from blocks import *
-from objects import *
 
-# register modules
-from utilities import *
-from processing import *
-from proteo import *
-from envfit import *
+# load objects
+from obj_compound import *
+from obj_sequence import *
+from obj_peak import *
+from obj_peaklist import *
+from obj_scan import *
 
-# register parsers
+# load modules
+from mod_basics import *
+from mod_signal import *
+from mod_calibration import *
+from mod_peakpicking import *
+from mod_proteo import *
+from mod_formulator import *
+from mod_envfit import *
+from mod_mascot import *
+from mod_utils import *
+
+# load parsers
 from parser_xy import parseXY
 from parser_mzxml import parseMZXML
 from parser_mzdata import parseMZDATA
